# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_MASK_METADATA = Metadata(
    id="c88d984dd58588f37c7a7cb282d5f5381d82b1e6.boutiques",
    name="mri_mask",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriMaskOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_mask(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output volume file"""


def mri_mask(
    input_volume: InputPathType,
    mask_volume: InputPathType,
    output_volume: str,
    xform: str | None = None,
    lta_src: str | None = None,
    lta_dst: str | None = None,
    threshold: float | None = None,
    npad: float | None = None,
    npad_vector: list[float] | None = None,
    npad_multi_vector: list[float] | None = None,
    abs_: bool = False,
    invert: bool = False,
    no_invert: bool = False,
    rh_labels: bool = False,
    lh_labels: bool = False,
    dilate: float | None = None,
    no_cerebellum: bool = False,
    oval_value: float | None = None,
    transfer_value: float | None = None,
    keep_mask_deletion_edits: bool = False,
    samseg: bool = False,
    runner: Runner | None = None,
) -> MriMaskOutputs:
    """
    Applies a mask volume (typically skull stripped).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file.
        mask_volume: Mask volume file.
        output_volume: Output volume file.
        xform: Apply M3Z/LTA to transform mask to the space of input volume\
            (identity.nofile possible, will invert if needed).
        lta_src: Source volume for -xform (if not available from the xform\
            file).
        lta_dst: Destination volume for -xform (if not available from the xform\
            file).
        threshold: Threshold mask volume at a given threshold (values <=\
            threshold considered zero).
        npad: Create a bounding box around the mask expanded by npad voxels in\
            each direction.
        npad_vector: Create a bounding box around the mask expanded by npad1\
            npad2 npad3 voxels in each direction.
        npad_multi_vector: Create a bounding box around the mask, expanded by\
            npad1a npad1b npad2a npad2b npad3a npad3b in each direction.
        abs_: Take absolute value before applying threshold.
        invert: Invert mask.
        no_invert: Turn off inversion of mask.
        rh_labels: Set mask in right hemisphere labels to 1 (assumes input mask\
            is an aseg).
        lh_labels: Set mask in left hemisphere labels to 1 (assumes input mask\
            is an aseg).
        dilate: Dilate mask N times before applying.
        no_cerebellum: Remove cerebellum from aseg mask (assumes input mask is\
            an aseg).
        oval_value: Use specified oval value as output instead of 0.
        transfer_value: Transfer only the specified voxel value from mask to\
            output.
        keep_mask_deletion_edits: Transfer voxel-deletion edits (voxels=1) from\
            mask to output volume.
        samseg: Assume mask is a SAMSEG segmentation and mask all non-brain\
            labels.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriMaskOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_MASK_METADATA)
    cargs = []
    cargs.append("mri_mask")
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(mask_volume))
    cargs.append(output_volume)
    if xform is not None:
        cargs.extend([
            "-xform",
            xform
        ])
    if lta_src is not None:
        cargs.extend([
            "-lta_src",
            lta_src
        ])
    if lta_dst is not None:
        cargs.extend([
            "-lta_dst",
            lta_dst
        ])
    if threshold is not None:
        cargs.extend([
            "-T",
            str(threshold)
        ])
    if npad is not None:
        cargs.extend([
            "-bb",
            str(npad)
        ])
    if npad_vector is not None:
        cargs.extend([
            "-bbm",
            *map(str, npad_vector)
        ])
    if npad_multi_vector is not None:
        cargs.extend([
            "-bbmm",
            *map(str, npad_multi_vector)
        ])
    if abs_:
        cargs.append("-abs")
    if invert:
        cargs.append("-invert")
    if no_invert:
        cargs.append("-no-invert")
    if rh_labels:
        cargs.append("-rh")
    if lh_labels:
        cargs.append("-lh")
    if dilate is not None:
        cargs.extend([
            "-dilate",
            str(dilate)
        ])
    if no_cerebellum:
        cargs.append("-no_cerebellum")
    if oval_value is not None:
        cargs.extend([
            "-oval",
            str(oval_value)
        ])
    if transfer_value is not None:
        cargs.extend([
            "-transfer",
            str(transfer_value)
        ])
    if keep_mask_deletion_edits:
        cargs.append("-keep_mask_deletion_edits")
    if samseg:
        cargs.append("-samseg")
    ret = MriMaskOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_MASK_METADATA",
    "MriMaskOutputs",
    "mri_mask",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SHRINKWRAP_METADATA = Metadata(
    id="12ec14d079d6b626e78773a4c0b060c225cdd33f.boutiques",
    name="mris_shrinkwrap",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisShrinkwrapOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_shrinkwrap(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inner_skull: OutputPathType
    """Output surface file representing the inner skull."""
    outer_skull: OutputPathType
    """Output surface file representing the outer skull."""
    outer_skin: OutputPathType
    """Output surface file representing the outer skin."""


def mris_shrinkwrap(
    volume: InputPathType,
    output_name: str,
    threshold: float | None = None,
    runner: Runner | None = None,
) -> MrisShrinkwrapOutputs:
    """
    Generate shrink-wrapped tessellations of the input volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        volume: Input image volume for shrink wrap.
        output_name: Base name for output surface files.
        threshold: Apply threshold to image before deforming on distance\
            transform.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisShrinkwrapOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SHRINKWRAP_METADATA)
    cargs = []
    cargs.append("mris_shrinkwrap")
    cargs.append(execution.input_file(volume))
    cargs.append(output_name)
    if threshold is not None:
        cargs.extend([
            "-t",
            str(threshold)
        ])
    ret = MrisShrinkwrapOutputs(
        root=execution.output_file("."),
        inner_skull=execution.output_file(output_name + "_inner_skull.tri"),
        outer_skull=execution.output_file(output_name + "_outer_skull.tri"),
        outer_skin=execution.output_file(output_name + "_outer_skin.tri"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SHRINKWRAP_METADATA",
    "MrisShrinkwrapOutputs",
    "mris_shrinkwrap",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CIFTI_CHANGE_MAPPING_METADATA = Metadata(
    id="53f8c510829c70200ad060f067b228f1aa52da65.boutiques",
    name="cifti-change-mapping",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class CiftiChangeMappingSeries:
    """
    set the mapping to series.
    """
    step: float
    """increment between series points"""
    start: float
    """start value of the series"""
    opt_unit_unit: str | None = None
    """select unit for series (default SECOND): unit identifier"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-series")
        cargs.append(str(self.step))
        cargs.append(str(self.start))
        if self.opt_unit_unit is not None:
            cargs.extend([
                "-unit",
                self.opt_unit_unit
            ])
        return cargs


@dataclasses.dataclass
class CiftiChangeMappingScalar:
    """
    set the mapping to scalar.
    """
    opt_name_file_file: str | None = None
    """specify names for the maps: text file containing map names, one per
    line"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-scalar")
        if self.opt_name_file_file is not None:
            cargs.extend([
                "-name-file",
                self.opt_name_file_file
            ])
        return cargs


@dataclasses.dataclass
class CiftiChangeMappingFromCifti:
    """
    copy mapping from another cifti file.
    """
    template_cifti: InputPathType
    """a cifti file containing the desired mapping"""
    direction: str
    """which direction to copy the mapping from"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-from-cifti")
        cargs.append(execution.input_file(self.template_cifti))
        cargs.append(self.direction)
        return cargs


class CiftiChangeMappingOutputs(typing.NamedTuple):
    """
    Output object returned when calling `cifti_change_mapping(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    cifti_out: OutputPathType
    """the output cifti file"""


def cifti_change_mapping(
    data_cifti: InputPathType,
    direction: str,
    cifti_out: str,
    series: CiftiChangeMappingSeries | None = None,
    scalar: CiftiChangeMappingScalar | None = None,
    from_cifti: CiftiChangeMappingFromCifti | None = None,
    runner: Runner | None = None,
) -> CiftiChangeMappingOutputs:
    """
    Convert to scalar, copy mapping, etc.
    
    Take an existing cifti file and change one of the mappings. Exactly one of
    -series, -scalar, or -from-cifti must be specified. The direction can be
    either an integer starting from 1, or the strings 'ROW' or 'COLUMN'.
    
    The argument to -unit must be one of the following:
    
    SECOND
    HERTZ
    METER
    RADIAN.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        data_cifti: the cifti file to use the data from.
        direction: which direction on <data-cifti> to replace the mapping.
        cifti_out: the output cifti file.
        series: set the mapping to series.
        scalar: set the mapping to scalar.
        from_cifti: copy mapping from another cifti file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `CiftiChangeMappingOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CIFTI_CHANGE_MAPPING_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-cifti-change-mapping")
    cargs.append(execution.input_file(data_cifti))
    cargs.append(direction)
    cargs.append(cifti_out)
    if series is not None:
        cargs.extend(series.run(execution))
    if scalar is not None:
        cargs.extend(scalar.run(execution))
    if from_cifti is not None:
        cargs.extend(from_cifti.run(execution))
    ret = CiftiChangeMappingOutputs(
        root=execution.output_file("."),
        cifti_out=execution.output_file(cifti_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CIFTI_CHANGE_MAPPING_METADATA",
    "CiftiChangeMappingFromCifti",
    "CiftiChangeMappingOutputs",
    "CiftiChangeMappingScalar",
    "CiftiChangeMappingSeries",
    "cifti_change_mapping",
]



"""
AFNI

AFNI (Analysis of Functional NeuroImages) is a leading software suite of C,
Python, R programs and shell scripts primarily developed for the analysis and
display of multiple MRI modalities: anatomical, functional MRI (FMRI) and
diffusion weighted (DW) data. It is freely available (both as open source code
and as precompiled binaries) for research purposes. The software is made to run
on virtually any Unix system with X11 and Motif displays. Binary packages are
provided for MacOS and Linux systems such as Fedora, CentOS/Red Hat and Ubuntu
(which includes the Windows Subsystem for Linux).

URL: https://afni.nimh.nih.gov/
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .abids_json_info_py import *
from .abids_json_tool_py import *
from .abids_tool import *
from .adjunct_apqc_tsnr_general import *
from .adjunct_aw_tableize_roi_info_py import *
from .adjunct_calc_mont_dims_py import *
from .adjunct_combine_str_py import *
from .adjunct_is_label_py import *
from .adjunct_make_script_and_rst_py import *
from .adjunct_select_str_py import *
from .adjunct_simplify_cost import *
from .adjunct_suma_fs_mask_and_qc import *
from .adjunct_suma_fs_roi_info import *
from .adjunct_tort_plot_dp_align import *
from .adwarp import *
from .afni import *
from .afni_batch_r import *
from .afni_check_omp import *
from .afni_history import *
from .afni_open import *
from .afni_proc_py import *
from .afni_run_r import *
from .afni_system_check_py import *
from .aiv import *
from .align_epi_anat import *
from .analyze_trace import *
from .ap_run_simple_rest import *
from .apqc_make_html import *
from .apqc_make_tcsh_py import *
from .apsearch import *
from .auto_warp_py import *
from .balloon import *
from .bayes_view import *
from .bayesian_group_ana_py import *
from .brain_skin import *
from .build_afni_py import *
from .cat_matvec import *
from .ccalc import *
from .cifti_tool import *
from .cjpeg import *
from .clust_exp_hist_table_py import *
from .clust_exp_stat_parse_py import *
from .column_cat import *
from .compare_surfaces import *
from .convert_cdiflist_to_grads import *
from .convert_dset import *
from .convert_surface import *
from .convex_hull import *
from .count import *
from .create_icosahedron import *
from .dcm2niix_afni import *
from .dicom_hdr import *
from .dicom_hinfo import *
from .dicom_to_raw import *
from .dimon import *
from .djpeg import *
from .drive_suma import *
from .dsetstat2p import *
from .dtistudio_fiberto_segments import *
from .epi_b0_correct import *
from .examine_xmat import *
from .fat_mat2d_plot_py import *
from .fat_mat_sel_py import *
from .fat_mat_tableize import *
from .fat_mvm_gridconv_py import *
from .fat_mvm_prep import *
from .fat_mvm_scripter_py import *
from .fat_proc_align_anat_pair import *
from .fat_proc_axialize_anat import *
from .fat_proc_connec_vis import *
from .fat_proc_convert_dcm_anat import *
from .fat_proc_convert_dcm_dwis import *
from .fat_proc_decmap import *
from .fat_proc_dwi_to_dt import *
from .fat_proc_filter_dwis import *
from .fat_proc_imit2w_from_t1w import *
from .fat_proc_map_to_dti import *
from .fat_proc_select_vols import *
from .fat_roi_row import *
from .fatcat_matplot import *
from .fdrval import *
from .fftest import *
from .file_tool import *
from .fim2 import *
from .find_variance_lines import *
from .firdesign import *
from .float_scan import *
from .from3d import *
from .fsread_annot import *
from .gen_epi_review_py import *
from .gen_group_command import *
from .gen_ss_review_scripts import *
from .gen_ss_review_table_py import *
from .get_afni_model_prf import *
from .get_afni_model_prf_6 import *
from .get_afni_model_prf_6_bad import *
from .gifti_tool import *
from .gltsymtest import *
from .help_format import *
from .im2niml import *
from .images_equal import *
from .imand import *
from .imaver import *
from .imcalc import *
from .imcat import *
from .imcutup import *
from .imdump import *
from .immask import *
from .imreg import *
from .imrotate import *
from .imstack import *
from .imstat import *
from .imupsam import *
from .init_user_dotfiles_py import *
from .inspec import *
from .iso_surface import *
from .make_color_map import *
from .make_pq_script_py import *
from .make_random_timing_py import *
from .make_stim_times_py import *
from .map_icosahedron import *
from .map_track_id import *
from .mba import *
from .meica_py import *
from .myget import *
from .neuro_deconvolve_py import *
from .nicat import *
from .niccc import *
from .nifti_tool import *
from .niml_feedme import *
from .nsize import *
from .p2dsetstat import *
from .parse_fs_lt_log_py import *
from .plugout_drive import *
from .plugout_ijk import *
from .plugout_tt import *
from .plugout_tta import *
from .prompt_popup import *
from .prompt_user import *
from .pta import *
from .qdelaunay import *
from .qhull import *
from .quick_alpha_vals_py import *
from .quickspec import *
from .quickspec_sl import *
from .quotize import *
from .r_pkgs_install import *
from .rba import *
from .rbox import *
from .read_matlab_files_py import *
from .realtime_receiver import *
from .retro_ts_py import *
from .rmz import *
from .roi2dataset import *
from .roigrow import *
from .rotcom import *
from .rsfgen import *
from .rtfeedme import *
from .samp_bias import *
from .scale_to_map import *
from .serial_helper import *
from .sfim import *
from .slow_surf_clustsim_py import *
from .spharm_deco import *
from .spharm_reco import *
from .stimband import *
from .strblast import *
from .suma_change_spec import *
from .suma_glxdino import *
from .surf2_vol_coord import *
from .surf_clust import *
from .surf_dist import *
from .surf_dset_info import *
from .surf_extrema import *
from .surf_fwhm import *
from .surf_info import *
from .surf_layers import *
from .surf_localstat import *
from .surf_measures import *
from .surf_mesh import *
from .surf_patch import *
from .surf_qual import *
from .surf_retino_map import *
from .surf_smooth import *
from .surf_to_surf import *
from .surface_metrics import *
from .tedana_wrapper_py import *
from .tfim import *
from .timing_tool_py import *
from .to3d import *
from .tokens import *
from .trr import *
from .uber_align_test_py import *
from .uber_proc_py import *
from .uber_skel import *
from .uber_subject_py import *
from .un_warp_epi_py import *
from .uniq_images import *
from .v_1d_apar2mat import *
from .v_1d_astrip import *
from .v_1d_bandpass import *
from .v_1d_bport import *
from .v_1d_correlate import *
from .v_1d_dw_grad_o_mat__ import *
from .v_1d_flag_motion import *
from .v_1d_marry import *
from .v_1d_nlfit import *
from .v_1d_rplot import *
from .v_1d_sem import *
from .v_1d_tool_py import *
from .v_1d_tsort import *
from .v_1d_upsample import *
from .v_1dcat import *
from .v_1ddot import *
from .v_1deval import *
from .v_1dfft import *
from .v_1dgen_arma11 import *
from .v_1dgrayplot import *
from .v_1dmatcalc import *
from .v_1dnorm import *
from .v_1dplot import *
from .v_1dplot_py import *
from .v_1dsound import *
from .v_1dsum import *
from .v_1dsvd import *
from .v_1dtranspose import *
from .v_24swap import *
from .v_2d_im_reg import *
from .v_2dcat import *
from .v_2perm import *
from .v_2swap import *
from .v_3_droimaker import *
from .v_3d_aboverlap import *
from .v_3d_acost import *
from .v_3d_afnito3_d import *
from .v_3d_afnito_analyze import *
from .v_3d_afnito_nifti import *
from .v_3d_afnito_niml import *
from .v_3d_afnito_raw import *
from .v_3d_allineate import *
from .v_3d_amp_to_rsfc import *
from .v_3d_anhist import *
from .v_3d_anova import *
from .v_3d_anova2 import *
from .v_3d_anova3 import *
from .v_3d_attribute import *
from .v_3d_auto_tcorrelate import *
from .v_3d_autobox import *
from .v_3d_automask import *
from .v_3d_ball_match import *
from .v_3d_bandpass import *
from .v_3d_blur_in_mask import *
from .v_3d_blur_to_fwhm import *
from .v_3d_brain_sync import *
from .v_3d_brain_voyagerto_afni import *
from .v_3d_brick_stat import *
from .v_3d_clip_level import *
from .v_3d_clust_count import *
from .v_3d_clust_sim import *
from .v_3d_clusterize import *
from .v_3d_cm import *
from .v_3d_compare_affine import *
from .v_3d_conformist import *
from .v_3d_convolve import *
from .v_3d_cruiseto_afni import *
from .v_3d_deconvolve import *
from .v_3d_degree_centrality import *
from .v_3d_depth_map import *
from .v_3d_despike import *
from .v_3d_detrend import *
from .v_3d_dft import *
from .v_3d_diff import *
from .v_3d_dteig import *
from .v_3d_dtto_dwi import *
from .v_3d_dtto_noisy_dwi import *
from .v_3d_dwito_dt import *
from .v_3d_dwuncert import *
from .v_3d_ecm import *
from .v_3d_edu_01_scale import *
from .v_3d_eigs_to_dt import *
from .v_3d_empty import *
from .v_3d_entropy import *
from .v_3d_errts_cormat import *
from .v_3d_exchange import *
from .v_3d_extract_group_in_corr import *
from .v_3d_extrema import *
from .v_3d_fdr import *
from .v_3d_fft import *
from .v_3d_friedman import *
from .v_3d_fwhmx import *
from .v_3d_gen_feature_dist import *
from .v_3d_gen_priors import *
from .v_3d_getrow import *
from .v_3d_grayplot import *
from .v_3d_group_in_corr import *
from .v_3d_hist import *
from .v_3d_icc import *
from .v_3d_intracranial import *
from .v_3d_inv_fmri import *
from .v_3d_isc import *
from .v_3d_kruskal_wallis import *
from .v_3d_lfcd import *
from .v_3d_lme import *
from .v_3d_lmer import *
from .v_3d_local_acf import *
from .v_3d_local_bistat import *
from .v_3d_local_histog import *
from .v_3d_local_pv import *
from .v_3d_local_svd import *
from .v_3d_local_unifize import *
from .v_3d_localstat import *
from .v_3d_lomb_scargle import *
from .v_3d_lrflip import *
from .v_3d_lss import *
from .v_3d_mann_whitney import *
from .v_3d_mask_to_ascii import *
from .v_3d_match import *
from .v_3d_mean import *
from .v_3d_median_filter import *
from .v_3d_mema import *
from .v_3d_mepfm import *
from .v_3d_mse import *
from .v_3d_mss import *
from .v_3d_multi_thresh import *
from .v_3d_mvm import *
from .v_3d_mvm_validator import *
from .v_3d_net_corr import *
from .v_3d_nlfim import *
from .v_3d_normality_test import *
from .v_3d_notes import *
from .v_3d_nwarp_adjust import *
from .v_3d_nwarp_apply import *
from .v_3d_nwarp_cat import *
from .v_3d_nwarp_funcs import *
from .v_3d_nwarp_xyz import *
from .v_3d_overlap import *
from .v_3d_par2_afni import *
from .v_3d_periodogram import *
from .v_3d_pfm import *
from .v_3d_polyfit import *
from .v_3d_pval import *
from .v_3d_pvmap import *
from .v_3d_qwarp import *
from .v_3d_rank import *
from .v_3d_rankizer import *
from .v_3d_re_ho import *
from .v_3d_reg_ana import *
from .v_3d_remlfit import *
from .v_3d_retino_phase import *
from .v_3d_roistats import *
from .v_3d_row_fillin import *
from .v_3d_rprog_demo import *
from .v_3d_rsfc import *
from .v_3d_seg import *
from .v_3d_setup_group_in_corr import *
from .v_3d_sharpen import *
from .v_3d_signatures import *
from .v_3d_skull_strip import *
from .v_3d_slice_ndice import *
from .v_3d_space_time_corr import *
from .v_3d_spat_norm import *
from .v_3d_stat_clust import *
from .v_3d_surf2_vol import *
from .v_3d_surf_mask import *
from .v_3d_synthesize import *
from .v_3d_tagalign import *
from .v_3d_tcat import *
from .v_3d_tcorr1_d import *
from .v_3d_tcorr_map import *
from .v_3d_tcorrelate import *
from .v_3d_tfilter import *
from .v_3d_tfitter import *
from .v_3d_threeto_rgb import *
from .v_3d_tnorm import *
from .v_3d_tortoiseto_here import *
from .v_3d_toutcount import *
from .v_3d_toy_prog import *
from .v_3d_tproject import *
from .v_3d_tqual import *
from .v_3d_track_id import *
from .v_3d_trfix import *
from .v_3d_tsgen import *
from .v_3d_tshift import *
from .v_3d_tsmooth import *
from .v_3d_tsort import *
from .v_3d_tsplit4_d import *
from .v_3d_tstat import *
from .v_3d_tto1_d import *
from .v_3d_twoto_complex import *
from .v_3d_undump import *
from .v_3d_unifize import *
from .v_3d_upsample import *
from .v_3d_vec_rgb_to_hsl import *
from .v_3d_vol2_surf import *
from .v_3d_warp import *
from .v_3d_warp_drive import *
from .v_3d_wilcoxon import *
from .v_3d_winsor import *
from .v_3d_xclust_sim import *
from .v_3d_xyzcat import *
from .v_3d_zcat import *
from .v_3d_zcutup import *
from .v_3d_zeropad import *
from .v_3d_zipper_zapper import *
from .v_3d_zregrid import *
from .v_3danisosmooth import *
from .v_3daxialize import *
from .v_3dbucket import *
from .v_3dcalc import *
from .v_3dclust import *
from .v_3dcopy import *
from .v_3ddelay import *
from .v_3ddot import *
from .v_3ddot_beta import *
from .v_3dedge3 import *
from .v_3dedgedog import *
from .v_3dfim_ import *
from .v_3dfractionize import *
from .v_3dhistog import *
from .v_3dinfill import *
from .v_3dinfo import *
from .v_3dkmeans import *
from .v_3dmask_svd import *
from .v_3dmask_tool import *
from .v_3dmaskave import *
from .v_3dmaskdump import *
from .v_3dmatcalc import *
from .v_3dmatmult import *
from .v_3dmaxdisp import *
from .v_3dmaxima import *
from .v_3dmerge import *
from .v_3dnewid import *
from .v_3dnvals import *
from .v_3dpc import *
from .v_3drefit import *
from .v_3drename import *
from .v_3dresample import *
from .v_3dretroicor import *
from .v_3drotate import *
from .v_3dsvm import *
from .v_3dsvm_linpredict import *
from .v_3dto_xdataset import *
from .v_3dttest__ import *
from .v_3dvolreg import *
from .v_4swap import *
from .v__1d_diff_mag import *
from .v__2dwarper import *
from .v__2dwarper_allin import *
from .v__4_daverage import *
from .v__add_edge import *
from .v__afni_env import *
from .v__afni_orient2_raimap import *
from .v__afni_orient_sign import *
from .v__afni_r_package_install import *
from .v__afni_refacer_make_master import *
from .v__afni_refacer_make_onebig_a12 import *
from .v__afni_refacer_run import *
from .v__afni_run_me import *
from .v__align_centers import *
from .v__align_partial_oblique import *
from .v__anaticor import *
from .v__animal_warper import *
from .v__atlasize import *
from .v__auto_tlrc import *
from .v__build_afni_xlib import *
from .v__center_distance import *
from .v__chauffeur_afni import *
from .v__check_for_afni_dset import *
from .v__clip_volume import *
from .v__clust_exp_cat_lab import *
from .v__clust_exp_run_shiny import *
from .v__command_globb import *
from .v__compute_gcor import *
from .v__compute_oc_weights import *
from .v__deblank_file_names import *
from .v__demo_prompt import *
from .v__dice_metric import *
from .v__diff_files import *
from .v__diff_tree import *
from .v__djunct_4d_imager import *
from .v__djunct_4d_slices_to_3d_vol import *
from .v__djunct_anonymize import *
from .v__djunct_dwi_selector import *
from .v__djunct_edgy_align_check import *
from .v__djunct_modal_smoothing_with_rep import *
from .v__djunct_montage_coordinator import *
from .v__djunct_overlap_check import *
from .v__djunct_ssw_intermed_edge_imgs import *
from .v__do_examples import *
from .v__electro_grid import *
from .v__examine_gen_feat_dists import *
from .v__extract_meica_ortvec import *
from .v__fast_roi import *
from .v__fat_tract_colorize import *
from .v__find_afni_dset_path import *
from .v__fix_fssphere import *
from .v__float_fix import *
from .v__from_rai import *
from .v__fs_roi_label import *
from .v__fslabel2dset import *
from .v__get_afni_dims import *
from .v__get_afni_id import *
from .v__get_afni_orient import *
from .v__get_afni_prefix import *
from .v__get_afni_res import *
from .v__get_afni_version import *
from .v__get_afni_view import *
from .v__grad_flip_test import *
from .v__grayplot import *
from .v__help_afni import *
from .v__is_oblique import *
from .v__iso_masks import *
from .v__make_label_table import *
from .v__make_plug_diff import *
from .v__measure_bb_thick import *
from .v__measure_erosion_thick import *
from .v__measure_in2out import *
from .v__move_to_series_dirs import *
from .v__no_ext import *
from .v__no_pound import *
from .v__noisy_skull_strip import *
from .v__np import *
from .v__parse_afni_name import *
from .v__purify_1_d import *
from .v__quiet_talkers import *
from .v__radial_correlate import *
from .v__rename_panga import *
from .v__reorder import *
from .v__retino_proc import *
from .v__roi_corr_mat import *
from .v__roi_decluster import *
from .v__roi_modal_grow import *
from .v__scale_volume import *
from .v__script_check import *
from .v__shift_volume import *
from .v__show_dynamic_range import *
from .v__simulate_motion import *
from .v__skull_strip_touch_up import *
from .v__snapshot_volreg import *
from .v__spharm_examples import *
from .v__sswarper import *
from .v__statauxcode import *
from .v__suma_acknowledge import *
from .v__suma_align_to_experiment import *
from .v__suma_fsvol_to_brik import *
from .v__suma_make_spec_caret import *
from .v__suma_make_spec_fs import *
from .v__suma_make_spec_sf import *
from .v__suma_renumber_fs import *
from .v__suma_reprefixize_spec import *
from .v__surf_smooth_heat_07_examples import *
from .v__surf_to_vol_spackle import *
from .v__t1scale import *
from .v__thickness_master import *
from .v__time_diff import *
from .v__to_mni_awarp import *
from .v__to_mni_qwarpar import *
from .v__to_rai import *
from .v__update_afni_binaries import *
from .v__vol_center import *
from .v__xyz_to_ijk import *
from .vecwarp import *
from .waver import *
from .whirlgif import *
from .xmat_tool_py import *



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

METRIC_CONVERT_METADATA = Metadata(
    id="053edd5cf7becabde4c75d80a9cb39af96fef852.boutiques",
    name="metric-convert",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class MetricConvertToNiftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricConvertToNifti | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    nifti_out: OutputPathType
    """the output nifti file"""


@dataclasses.dataclass
class MetricConvertToNifti:
    """
    convert metric to nifti.
    """
    metric_in: InputPathType
    """the metric to convert"""
    nifti_out: str
    """the output nifti file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-to-nifti")
        cargs.append(execution.input_file(self.metric_in))
        cargs.append(self.nifti_out)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> MetricConvertToNiftiOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `MetricConvertToNiftiOutputs`).
        """
        ret = MetricConvertToNiftiOutputs(
            root=execution.output_file("."),
            nifti_out=execution.output_file(self.nifti_out),
        )
        return ret


class MetricConvertFromNiftiOutputs(typing.NamedTuple):
    """
    Output object returned when calling `MetricConvertFromNifti | None(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    metric_out: OutputPathType
    """the output metric file"""


@dataclasses.dataclass
class MetricConvertFromNifti:
    """
    convert nifti to metric.
    """
    nifti_in: InputPathType
    """the nifti file to convert"""
    surface_in: InputPathType
    """surface file to use number of vertices and structure from"""
    metric_out: str
    """the output metric file"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-from-nifti")
        cargs.append(execution.input_file(self.nifti_in))
        cargs.append(execution.input_file(self.surface_in))
        cargs.append(self.metric_out)
        return cargs
    
    def outputs(
        self,
        execution: Execution,
    ) -> MetricConvertFromNiftiOutputs:
        """
        Collect output file paths.
        
        Args:
            execution: The execution object.
        Returns:
            NamedTuple of outputs (described in `MetricConvertFromNiftiOutputs`).
        """
        ret = MetricConvertFromNiftiOutputs(
            root=execution.output_file("."),
            metric_out=execution.output_file(self.metric_out),
        )
        return ret


class MetricConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `metric_convert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    to_nifti: MetricConvertToNiftiOutputs | None
    """Outputs from `MetricConvertToNifti`."""
    from_nifti: MetricConvertFromNiftiOutputs | None
    """Outputs from `MetricConvertFromNifti`."""


def metric_convert(
    to_nifti: MetricConvertToNifti | None = None,
    from_nifti: MetricConvertFromNifti | None = None,
    runner: Runner | None = None,
) -> MetricConvertOutputs:
    """
    Convert metric file to fake nifti.
    
    The purpose of this command is to convert between metric files and nifti1 so
    that gifti-unaware programs can operate on the data. You must specify
    exactly one of the options.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        to_nifti: convert metric to nifti.
        from_nifti: convert nifti to metric.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MetricConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(METRIC_CONVERT_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-metric-convert")
    if to_nifti is not None:
        cargs.extend(to_nifti.run(execution))
    if from_nifti is not None:
        cargs.extend(from_nifti.run(execution))
    ret = MetricConvertOutputs(
        root=execution.output_file("."),
        to_nifti=to_nifti.outputs(execution) if to_nifti else None,
        from_nifti=from_nifti.outputs(execution) if from_nifti else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "METRIC_CONVERT_METADATA",
    "MetricConvertFromNifti",
    "MetricConvertFromNiftiOutputs",
    "MetricConvertOutputs",
    "MetricConvertToNifti",
    "MetricConvertToNiftiOutputs",
    "metric_convert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_SUB_METADATA = Metadata(
    id="e00d073a22a6b171f18d9558a8e06d7992bcb374.boutiques",
    name="fsl_sub",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslSubOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_sub(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fsl_sub(
    arch: str | None = None,
    coprocessor: str | None = None,
    coprocessor_multi: float | None = None,
    coprocessor_class: str | None = None,
    coprocessor_class_strict: bool = False,
    coprocessor_toolkit: str | None = None,
    usescript: bool = False,
    jobhold: str | None = None,
    not_requeueable: bool = False,
    array_hold: str | None = None,
    logdir: str | None = None,
    mailoptions: str | None = None,
    mailto: str | None = "root@fe8ea96c3a1a",
    novalidation: bool = False,
    name: str | None = None,
    priority: str | None = None,
    queue_: str | None = None,
    resource_: str | None = None,
    delete_job: str | None = None,
    jobram: float | None = None,
    parallelenv_threads: str | None = None,
    array_task: str | None = None,
    array_native: str | None = None,
    array_limit: float | None = None,
    keep_jobscript: bool = False,
    project: str | None = None,
    noramsplit: bool = False,
    jobtime: float | None = None,
    has_coprocessor: str | None = None,
    has_queues: bool = False,
    show_config: bool = False,
    verbose: bool = False,
    version: bool = False,
    fileisimage: InputPathType | None = None,
    runner: Runner | None = None,
) -> FslSubOutputs:
    """
    FSL cluster submission tool.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        arch: Architectures not available.
        coprocessor: No co-processor configured - ignored.
        coprocessor_multi: No co-processor configured - ignored.
        coprocessor_class: No co-processor classes configured - ignored.
        coprocessor_class_strict: No co-processor classes configured - ignored.
        coprocessor_toolkit: No co-processor toolkits configured - ignored.
        usescript: Use flags embedded in scripts to set queuing options - not\
            supported.
        jobhold: Place a hold on this task until specified job id has\
            completed.
        not_requeueable: Job cannot be requeued in the event of a node failure.
        array_hold: Not supported - will be converted to simple job hold.
        logdir: Where to output logfiles.
        mailoptions: Email notification options (ignored).
        mailto: Email notification recipients (ignored).
        novalidation: Don't check for presence of script/binary in your\
            searchpath.
        name: Specify job name as it will appear on queue.
        priority: Specify job priority (not supported).
        queue_: Specify the queue for the job (irrelevant if not running in a\
            cluster environment).
        resource_: Pass a resource request or constraint string through to the\
            job scheduler.
        delete_job: Deletes a queued/running job.
        jobram: Max total RAM required for job (integer in GB).
        parallelenv_threads: No parallel environments configured.
        array_task: Specify a task file of commands to execute in parallel.
        array_native: Binary/Script will handle array task internally (mutually\
            exclusive with --array_task).
        array_limit: Specify the maximum number of parallel job sub-tasks to\
            run concurrently.
        keep_jobscript: Whether to create and save a job submission script.
        project: Specify the project (not relevant when not running in a\
            cluster environment).
        noramsplit: Disable RAM splitting (not relevant when not running in a\
            cluster environment).
        jobtime: Estimated job length in minutes, used to automatically choose\
            the queue name.
        has_coprocessor: fsl_sub returns with exit code of 0 if specified\
            coprocessor is configured.
        has_queues: fsl_sub returns with exit code of 0 if there's a compute\
            cluster with queues configured.
        show_config: Display the configuration currently in force.
        verbose: Verbose mode.
        version: Show program's version number and exit.
        fileisimage: If <file> already exists and is an MRI image file, do\
            nothing and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslSubOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_SUB_METADATA)
    cargs = []
    cargs.append("fsl_sub")
    if arch is not None:
        cargs.extend([
            "-a",
            arch
        ])
    if coprocessor is not None:
        cargs.extend([
            "-c",
            coprocessor
        ])
    if coprocessor_multi is not None:
        cargs.extend([
            "--coprocessor_multi",
            str(coprocessor_multi)
        ])
    if coprocessor_class is not None:
        cargs.extend([
            "--coprocessor_class",
            coprocessor_class
        ])
    if coprocessor_class_strict:
        cargs.append("--coprocessor_class_strict")
    if coprocessor_toolkit is not None:
        cargs.extend([
            "--coprocessor_toolkit",
            coprocessor_toolkit
        ])
    if usescript:
        cargs.append("-F")
    if jobhold is not None:
        cargs.extend([
            "-j",
            jobhold
        ])
    if not_requeueable:
        cargs.append("--not_requeueable")
    if array_hold is not None:
        cargs.extend([
            "--array_hold",
            array_hold
        ])
    if logdir is not None:
        cargs.extend([
            "-l",
            logdir
        ])
    if mailoptions is not None:
        cargs.extend([
            "-m",
            mailoptions
        ])
    if mailto is not None:
        cargs.extend([
            "-M",
            mailto
        ])
    if novalidation:
        cargs.append("-n")
    if name is not None:
        cargs.extend([
            "-N",
            name
        ])
    if priority is not None:
        cargs.extend([
            "-p",
            priority
        ])
    if queue_ is not None:
        cargs.extend([
            "-q",
            queue_
        ])
    if resource_ is not None:
        cargs.extend([
            "-r",
            resource_
        ])
    if delete_job is not None:
        cargs.extend([
            "--delete_job",
            delete_job
        ])
    if jobram is not None:
        cargs.extend([
            "-R",
            str(jobram)
        ])
    if parallelenv_threads is not None:
        cargs.extend([
            "-s",
            parallelenv_threads
        ])
    if array_task is not None:
        cargs.extend([
            "-t",
            array_task
        ])
    if array_native is not None:
        cargs.extend([
            "--array_native",
            array_native
        ])
    if array_limit is not None:
        cargs.extend([
            "-x",
            str(array_limit)
        ])
    if keep_jobscript:
        cargs.append("--keep_jobscript")
    if project is not None:
        cargs.extend([
            "--project",
            project
        ])
    if noramsplit:
        cargs.append("-S")
    if jobtime is not None:
        cargs.extend([
            "-T",
            str(jobtime)
        ])
    if has_coprocessor is not None:
        cargs.extend([
            "--has_coprocessor",
            has_coprocessor
        ])
    if has_queues:
        cargs.append("--has_queues")
    if show_config:
        cargs.append("--show_config")
    if verbose:
        cargs.append("-v")
    if version:
        cargs.append("-V")
    if fileisimage is not None:
        cargs.extend([
            "-z",
            execution.input_file(fileisimage)
        ])
    ret = FslSubOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_SUB_METADATA",
    "FslSubOutputs",
    "fsl_sub",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MAP_TO_BASE_METADATA = Metadata(
    id="8c862381695fa9287f6e4158898dca7536db24a8.boutiques",
    name="map_to_base",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MapToBaseOutputs(typing.NamedTuple):
    """
    Output object returned when calling `map_to_base(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_long_mri: OutputPathType
    """Output in base/mri directory when mapped from a longitudinal
    directory."""
    output_long_surf: OutputPathType
    """Output in base/surf directory when mapped from a longitudinal
    directory."""
    output_cross_mri: OutputPathType
    """Output in base/mri directory when mapped from a cross-sectional
    directory."""
    output_cross_surf: OutputPathType
    """Output in base/surf directory when mapped from a cross-sectional
    directory."""


def map_to_base(
    baseid: str,
    tpid: str,
    input_image: str,
    resample_type: str,
    cross: str | None = None,
    runner: Runner | None = None,
) -> MapToBaseOutputs:
    """
    Maps an image or surface from a time point directory (either cross-sectional or
    longitudinal) to the base space and outputs it in the appropriate base
    directory.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        baseid: Identifier of the base.
        tpid: Identifier of the time point, without the '.long.baseid' suffix.
        input_image: Input image, e.g., norm.mgz, aseg.mgz, lh.white.
        resample_type: Resample type. 'interpolate' for norm, T1, orig;\
            'nearest' for aseg; 'surface' for surfaces.
        cross: If '1', input is from cross sectionals; default is to use\
            longitudinal directories.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MapToBaseOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MAP_TO_BASE_METADATA)
    cargs = []
    cargs.append("map_to_base")
    cargs.append(baseid)
    cargs.append(tpid)
    cargs.append(input_image)
    cargs.append(resample_type)
    if cross is not None:
        cargs.append(cross)
    ret = MapToBaseOutputs(
        root=execution.output_file("."),
        output_long_mri=execution.output_file(baseid + "/mri/" + tpid + "-long." + input_image),
        output_long_surf=execution.output_file(baseid + "/surf/" + tpid + "-long." + input_image),
        output_cross_mri=execution.output_file(baseid + "/mri/" + tpid + "-cross." + input_image),
        output_cross_surf=execution.output_file(baseid + "/surf/" + tpid + "-cross." + input_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MAP_TO_BASE_METADATA",
    "MapToBaseOutputs",
    "map_to_base",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLMATHS_FSL_METADATA = Metadata(
    id="1ba348f3e9fa1acbe3b64d58f1387f609d1c083e.boutiques",
    name="fslmaths.fsl",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FslmathsFslOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslmaths_fsl(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """The resultant output image after applying the specified operations."""


def fslmaths_fsl(
    first_input: InputPathType,
    operations_and_inputs: str,
    output_image: str,
    runner: Runner | None = None,
) -> FslmathsFslOutputs:
    """
    FSLmaths: part of FMRIB Software Library (FSL) for manipulating images via
    various mathematical operations.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        first_input: First input image for fslmaths operations.
        operations_and_inputs: Operations and inputs to be applied on the first\
            image.
        output_image: Output image file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslmathsFslOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLMATHS_FSL_METADATA)
    cargs = []
    cargs.append("fslmaths")
    cargs.append(execution.input_file(first_input))
    cargs.append(operations_and_inputs)
    cargs.append(output_image)
    ret = FslmathsFslOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_image + ".nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLMATHS_FSL_METADATA",
    "FslmathsFslOutputs",
    "fslmaths_fsl",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SEGMENT_SUBJECT_SC_METADATA = Metadata(
    id="02733a36fda91e4ab91ac726bedcbf25c9c93313.boutiques",
    name="segment_subject_sc",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SegmentSubjectScOutputs(typing.NamedTuple):
    """
    Output object returned when calling `segment_subject_sc(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_xfm_file: OutputPathType
    """Output transform file (xfm)"""


def segment_subject_sc(
    invol: InputPathType,
    outxfm: InputPathType,
    log: str | None = "outdir/talarach.log",
    debug: bool = False,
    runner: Runner | None = None,
) -> SegmentSubjectScOutputs:
    """
    Front-end for MINC's mritotal. Computes the Talairach transform for mapping the
    input volume to the MNI305 space.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        invol: Input volume.
        outxfm: Output xfm file.
        log: Log file. Default is outdir/talarach.log.
        debug: Turn on debugging.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SegmentSubjectScOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SEGMENT_SUBJECT_SC_METADATA)
    cargs = []
    cargs.append("mri_nu_correct.mni")
    cargs.extend([
        "-i",
        "-" + execution.input_file(invol)
    ])
    cargs.extend([
        "-xfm",
        "-" + execution.input_file(outxfm)
    ])
    if log is not None:
        cargs.extend([
            "--log",
            log
        ])
    if debug:
        cargs.append("--debug")
    ret = SegmentSubjectScOutputs(
        root=execution.output_file("."),
        output_xfm_file=execution.output_file(pathlib.Path(outxfm).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SEGMENT_SUBJECT_SC_METADATA",
    "SegmentSubjectScOutputs",
    "segment_subject_sc",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SURFACE_GENERATE_INFLATED_METADATA = Metadata(
    id="6eea5f830d4577873fce8195913d40900b759e3e.boutiques",
    name="surface-generate-inflated",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


class SurfaceGenerateInflatedOutputs(typing.NamedTuple):
    """
    Output object returned when calling `surface_generate_inflated(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inflated_surface_out: OutputPathType
    """the output inflated surface"""
    very_inflated_surface_out: OutputPathType
    """the output very inflated surface"""


def surface_generate_inflated(
    anatomical_surface_in: InputPathType,
    inflated_surface_out: str,
    very_inflated_surface_out: str,
    opt_iterations_scale_iterations_scale_value: float | None = None,
    runner: Runner | None = None,
) -> SurfaceGenerateInflatedOutputs:
    """
    Surface generate inflated.
    
    Generate inflated and very inflated surfaces. The output surfaces are
    'matched' (have same XYZ range) to the anatomical surface. In most cases, an
    iterations-scale of 1.0 (default) is sufficient. However, if the surface
    contains a large number of vertices (150,000), try an iterations-scale of
    2.5.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        anatomical_surface_in: the anatomical surface.
        inflated_surface_out: the output inflated surface.
        very_inflated_surface_out: the output very inflated surface.
        opt_iterations_scale_iterations_scale_value: optional iterations\
            scaling: iterations-scale value.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SurfaceGenerateInflatedOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SURFACE_GENERATE_INFLATED_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-surface-generate-inflated")
    cargs.append(execution.input_file(anatomical_surface_in))
    cargs.append(inflated_surface_out)
    cargs.append(very_inflated_surface_out)
    if opt_iterations_scale_iterations_scale_value is not None:
        cargs.extend([
            "-iterations-scale",
            str(opt_iterations_scale_iterations_scale_value)
        ])
    ret = SurfaceGenerateInflatedOutputs(
        root=execution.output_file("."),
        inflated_surface_out=execution.output_file(inflated_surface_out),
        very_inflated_surface_out=execution.output_file(very_inflated_surface_out),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SURFACE_GENERATE_INFLATED_METADATA",
    "SurfaceGenerateInflatedOutputs",
    "surface_generate_inflated",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IMDUMP_METADATA = Metadata(
    id="7f8451c2da7ec8cbf2c32a069270cdd298deaee7.boutiques",
    name="imdump",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ImdumpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `imdump(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    stdout: OutputPathType
    """Nonzero pixels in the format: x-index y-index value, one pixel per
    line."""


def imdump(
    input_image: InputPathType,
    runner: Runner | None = None,
) -> ImdumpOutputs:
    """
    Prints out nonzero pixels in an image.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_image: Input image file to be processed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ImdumpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IMDUMP_METADATA)
    cargs = []
    cargs.append("imdump")
    cargs.append(execution.input_file(input_image))
    ret = ImdumpOutputs(
        root=execution.output_file("."),
        stdout=execution.output_file("stdout.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IMDUMP_METADATA",
    "ImdumpOutputs",
    "imdump",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QUOTIZE_METADATA = Metadata(
    id="6c4eed808717d714bfc54617b8f18dc0c60724e7.boutiques",
    name="quotize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class QuotizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `quotize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    array_output: OutputPathType
    """Generated C array of strings file"""


def quotize(
    name: str,
    input_file: InputPathType,
    output_file: InputPathType,
    runner: Runner | None = None,
) -> QuotizeOutputs:
    """
    Turns a text file into a C array of strings initialized into an array 'char
    *name[]'.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        name: The name to be used for the array of strings.
        input_file: Input text file to be converted.
        output_file: Output file which will contain the C array of strings.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QuotizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QUOTIZE_METADATA)
    cargs = []
    cargs.append("quotize")
    cargs.append(name)
    cargs.append(execution.input_file(input_file))
    cargs.append(execution.input_file(output_file))
    ret = QuotizeOutputs(
        root=execution.output_file("."),
        array_output=execution.output_file(pathlib.Path(output_file).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QUOTIZE_METADATA",
    "QuotizeOutputs",
    "quotize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_ENTROPY_METADATA = Metadata(
    id="5707967e94407108591e9f09a18741e3c81c9aed.boutiques",
    name="mris_entropy",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisEntropyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_entropy(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file containing the computed entropy"""


def mris_entropy(
    subject: str,
    hemi: str,
    wfile: InputPathType,
    curvfile: InputPathType,
    average_iterations: float | None = 0,
    normalize: bool = False,
    runner: Runner | None = None,
) -> MrisEntropyOutputs:
    """
    Computes the entropy of a surface activation pattern for FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: Subject ID.
        hemi: Hemisphere (e.g., lh or rh).
        wfile: Weight file for surface.
        curvfile: Curvature file for input.
        average_iterations: Specify number of curvature averaging iterations\
            (default=0).
        normalize: Normalize curvature before writing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisEntropyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_ENTROPY_METADATA)
    cargs = []
    cargs.append("mris_entropy")
    cargs.append(subject)
    cargs.append(hemi)
    cargs.append(execution.input_file(wfile))
    cargs.append(execution.input_file(curvfile))
    if average_iterations is not None:
        cargs.extend([
            "-a",
            str(average_iterations)
        ])
    if normalize:
        cargs.append("-n")
    ret = MrisEntropyOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(subject + "_" + hemi + "_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_ENTROPY_METADATA",
    "MrisEntropyOutputs",
    "mris_entropy",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_PROJECT_END_POINTS_METADATA = Metadata(
    id="93cde90208fae7700f6f02d3a5122b37ae3a77f6.boutiques",
    name="dmri_projectEndPoints",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriProjectEndPointsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_project_end_points(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_left_overlay: OutputPathType
    """Overlay file for left hemisphere surface"""
    out_right_overlay: OutputPathType
    """Overlay file for right hemisphere surface"""


def dmri_project_end_points(
    streamline_file: InputPathType,
    left_surface_file: InputPathType,
    right_surface_file: InputPathType,
    left_overlay_file: str,
    right_overlay_file: str,
    reference_image: InputPathType,
    runner: Runner | None = None,
) -> DmriProjectEndPointsOutputs:
    """
    A tool for projecting the endpoints of streamlines onto cortical surfaces,
    producing overlay files for visualization.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        streamline_file: Input streamline file (e.g. streamlineFile.trk).
        left_surface_file: Left hemisphere surface file (e.g.\
            surfaceFile_lh.orig).
        right_surface_file: Right hemisphere surface file (e.g.\
            surfaceFile_rh.orig).
        left_overlay_file: Output overlay file for left hemisphere.
        right_overlay_file: Output overlay file for right hemisphere.
        reference_image: Reference image for the projections.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriProjectEndPointsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_PROJECT_END_POINTS_METADATA)
    cargs = []
    cargs.append("dmri_projectEndPoints")
    cargs.extend([
        "-i",
        execution.input_file(streamline_file)
    ])
    cargs.extend([
        "-sl",
        execution.input_file(left_surface_file)
    ])
    cargs.extend([
        "-sr",
        execution.input_file(right_surface_file)
    ])
    cargs.extend([
        "-ol",
        left_overlay_file
    ])
    cargs.extend([
        "-or",
        right_overlay_file
    ])
    cargs.extend([
        "-ri",
        execution.input_file(reference_image)
    ])
    ret = DmriProjectEndPointsOutputs(
        root=execution.output_file("."),
        out_left_overlay=execution.output_file(left_overlay_file),
        out_right_overlay=execution.output_file(right_overlay_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_PROJECT_END_POINTS_METADATA",
    "DmriProjectEndPointsOutputs",
    "dmri_project_end_points",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FNAME2STEM_METADATA = Metadata(
    id="94f87797696ba85f60d558b2cd4d3fefe8915133.boutiques",
    name="fname2stem",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Fname2stemOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fname2stem(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fname2stem(
    filename: str,
    runner: Runner | None = None,
) -> Fname2stemOutputs:
    """
    Converts the name of a file to a stem. Example: f.mgh, f.nii, f.nii.gz would
    return f.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        filename: The name of the file to convert to a stem. The file does not\
            need to exist.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Fname2stemOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FNAME2STEM_METADATA)
    cargs = []
    cargs.append("fname2stem")
    cargs.append(filename)
    ret = Fname2stemOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FNAME2STEM_METADATA",
    "Fname2stemOutputs",
    "fname2stem",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__RADIAL_CORRELATE_METADATA = Metadata(
    id="1cbb44d20d4e3ca23ba7981bb4c49932fce75bf0.boutiques",
    name="@radial_correlate",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VRadialCorrelateOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__radial_correlate(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corr_volumes: OutputPathType | None
    """Directory containing correlation volumes"""


def v__radial_correlate(
    input_files: list[InputPathType],
    results_dir: str | None = None,
    do_corr: str | None = None,
    do_clust: str | None = None,
    mask_dset: InputPathType | None = None,
    cthresh: float | None = None,
    frac_limit: float | None = None,
    sphere_rad: float | None = None,
    use_3dmerge: str | None = None,
    percentile: float | None = None,
    min_thr: float | None = None,
    nfirst: float | None = None,
    ver: bool = False,
    verbose: bool = False,
    help_: bool = False,
    hist: bool = False,
    corr_mask: str | None = None,
    do_clean: str | None = None,
    polort: float | None = None,
    merge_frad: float | None = None,
    runner: Runner | None = None,
) -> VRadialCorrelateOutputs:
    """
    Check datasets for correlation artifacts.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_files: A list of EPI datasets.
        results_dir: Results directory for correlations.
        do_corr: Create correlation volumes (yes/no).
        do_clust: Cluster correlation volumes (yes/no).
        mask_dset: Specify a mask dataset to replace automask.
        cthresh: Threshold on correlation values.
        frac_limit: Minimum mask fraction surviving cluster.
        sphere_rad: Generate correlations within voxel spheres.
        use_3dmerge: Use 3dmerge rather than 3dLocalstat (yes/no).
        percentile: Percentile to use as threshold.
        min_thr: Minimum percentile threshold to be considered.
        nfirst: Number of initial TRs to remove.
        ver: Show version number.
        verbose: Make verbose: set echo.
        help_: Show help.
        hist: Show modification history.
        corr_mask: Mask time series before correlation blurring (yes/no).
        do_clean: Clean up at end, leaving only correlations (yes/no).
        polort: Detrend time series with given polynomial degree.
        merge_frad: Specify a radius fraction for 3dmerge blurring.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VRadialCorrelateOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__RADIAL_CORRELATE_METADATA)
    cargs = []
    cargs.append("@radial_correlate")
    cargs.extend([execution.input_file(f) for f in input_files])
    if results_dir is not None:
        cargs.extend([
            "-rdir",
            results_dir
        ])
    if do_corr is not None:
        cargs.extend([
            "-do_corr",
            do_corr
        ])
    if do_clust is not None:
        cargs.extend([
            "-do_clust",
            do_clust
        ])
    if mask_dset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dset)
        ])
    if cthresh is not None:
        cargs.extend([
            "-cthresh",
            str(cthresh)
        ])
    if frac_limit is not None:
        cargs.extend([
            "-frac_limit",
            str(frac_limit)
        ])
    if sphere_rad is not None:
        cargs.extend([
            "-sphere_rad",
            str(sphere_rad)
        ])
    if use_3dmerge is not None:
        cargs.extend([
            "-use_3dmerge",
            use_3dmerge
        ])
    if percentile is not None:
        cargs.extend([
            "-percentile",
            str(percentile)
        ])
    if min_thr is not None:
        cargs.extend([
            "-min_thr",
            str(min_thr)
        ])
    if nfirst is not None:
        cargs.extend([
            "-nfirst",
            str(nfirst)
        ])
    if ver:
        cargs.append("-ver")
    if verbose:
        cargs.append("-verb")
    if help_:
        cargs.append("-help")
    if hist:
        cargs.append("-hist")
    if corr_mask is not None:
        cargs.extend([
            "-corr_mask",
            corr_mask
        ])
    if do_clean is not None:
        cargs.extend([
            "-do_clean",
            do_clean
        ])
    if polort is not None:
        cargs.extend([
            "-polort",
            str(polort)
        ])
    if merge_frad is not None:
        cargs.extend([
            "-merge_frad",
            str(merge_frad)
        ])
    ret = VRadialCorrelateOutputs(
        root=execution.output_file("."),
        corr_volumes=execution.output_file(results_dir + "/correlation_volumes") if (results_dir is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VRadialCorrelateOutputs",
    "V__RADIAL_CORRELATE_METADATA",
    "v__radial_correlate",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SBTIV_METADATA = Metadata(
    id="a7417d0462b1e0c51153427b6aeb6a3ba11a4eb6.boutiques",
    name="sbtiv",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SbtivOutputs(typing.NamedTuple):
    """
    Output object returned when calling `sbtiv(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType | None
    """Intracranial stats output file."""


def sbtiv(
    input_file: InputPathType,
    output_file: InputPathType | None = None,
    labels_file: InputPathType | None = None,
    runner: Runner | None = None,
) -> SbtivOutputs:
    """
    Tool to calculate the total intracranial volume of a subject by summing
    individual volumes computed by samseg.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Volume stats input file.
        output_file: Intracranial stats output file.
        labels_file: File containing a list of intracranial structure\
            labelnames to include in the calculation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SbtivOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SBTIV_METADATA)
    cargs = []
    cargs.append("sbtiv")
    cargs.append(execution.input_file(input_file))
    if output_file is not None:
        cargs.extend([
            "-o",
            execution.input_file(output_file)
        ])
    if labels_file is not None:
        cargs.extend([
            "-l",
            execution.input_file(labels_file)
        ])
    ret = SbtivOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(pathlib.Path(output_file).name) if (output_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SBTIV_METADATA",
    "SbtivOutputs",
    "sbtiv",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SWI_PROCESS_METADATA = Metadata(
    id="f14e6e76e9a671b5dc9172a46d7f994a3f809460.boutiques",
    name="swi_process",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SwiProcessOutputs(typing.NamedTuple):
    """
    Output object returned when calling `swi_process(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    swi_output_file: OutputPathType
    """SWI processed output image"""


def swi_process(
    magnitude_image: InputPathType,
    phase_image: InputPathType,
    swi_output: str,
    stddev: float | None = None,
    phase_mask_cutoff: float | None = None,
    phase_mask_right_cutoff: float | None = None,
    sigmoid_a: float | None = None,
    sigmoid_b: float | None = None,
    phase_multiplications: float | None = None,
    mip_level: float | None = None,
    phase_mask_method: str | None = None,
    runner: Runner | None = None,
) -> SwiProcessOutputs:
    """
    Process the Susceptibility-weighted images. Ensure the inputs are post-phase
    unwrapping using PRELUDE.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        magnitude_image: The magnitude image (Output from the PRELUDE program).
        phase_image: The phase image (Output from the PRELUDE program).
        swi_output: Name of the SWI processed output image.
        stddev: Specify the standard deviation of the Gaussian Smoothing\
            Filter. Default is 2.0.
        phase_mask_cutoff: Specify the negative phase mask cutoff frequency (in\
            radians). Default is the minimum value of the phase image.
        phase_mask_right_cutoff: Specify the positive phase mask cutoff\
            frequency (in radians). Default is the maximum value of the phase\
            image.
        sigmoid_a: Specify 'a' for the sigmoid formula\
            f(phase)=1/(1+exp(-a*(phase-b))). Default is 1.0. Meaningless with\
            phase_method != sigmoid.
        sigmoid_b: Specify 'b' for the sigmoid formula\
            f(phase)=1/(1+exp(-a*(phase-b))). Default is 0.0. Meaningless with\
            phase_method != sigmoid.
        phase_multiplications: Specify the number of phase multiplications.\
            Default is 4.
        mip_level: Specify the number of levels of mIP across the y direction.\
            Default is 4.
        phase_mask_method: Specify the phase mask method. One of negative,\
            positive, symmetric, asymmetric, sigmoid. Default is negative.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SwiProcessOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SWI_PROCESS_METADATA)
    cargs = []
    cargs.append("swi_process")
    cargs.append(execution.input_file(magnitude_image))
    cargs.append(execution.input_file(phase_image))
    cargs.append(swi_output)
    if stddev is not None:
        cargs.extend([
            "--stddev",
            str(stddev)
        ])
    if phase_mask_cutoff is not None:
        cargs.extend([
            "--phase_mask_cutoff",
            str(phase_mask_cutoff)
        ])
    if phase_mask_right_cutoff is not None:
        cargs.extend([
            "--phase_mask_right_cutoff",
            str(phase_mask_right_cutoff)
        ])
    if sigmoid_a is not None:
        cargs.extend([
            "--sigmoid_a",
            str(sigmoid_a)
        ])
    if sigmoid_b is not None:
        cargs.extend([
            "--sigmoid_b",
            str(sigmoid_b)
        ])
    if phase_multiplications is not None:
        cargs.extend([
            "--phase_multiplications",
            str(phase_multiplications)
        ])
    if mip_level is not None:
        cargs.extend([
            "--mip_level",
            str(mip_level)
        ])
    if phase_mask_method is not None:
        cargs.extend([
            "--phase_mask_method",
            phase_mask_method
        ])
    ret = SwiProcessOutputs(
        root=execution.output_file("."),
        swi_output_file=execution.output_file(swi_output),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SWI_PROCESS_METADATA",
    "SwiProcessOutputs",
    "swi_process",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SWI_PREPROCESS_METADATA = Metadata(
    id="9c092f99975ad21400c19882fe546f899bd6d1ce.boutiques",
    name="swi_preprocess",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SwiPreprocessOutputs(typing.NamedTuple):
    """
    Output object returned when calling `swi_preprocess(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_magnitude_file: OutputPathType
    """Output magnitude file in NIfTI format."""
    output_phase_file: OutputPathType
    """Output phase file in NIfTI format."""


def swi_preprocess(
    scanner: typing.Literal["ge", "siemens", "philips"],
    out_magnitude: str,
    out_phase: str,
    ge_file: InputPathType | None = None,
    philips_file: InputPathType | None = None,
    siemens_magnitude: InputPathType | None = None,
    siemens_phase: InputPathType | None = None,
    runner: Runner | None = None,
) -> SwiPreprocessOutputs:
    """
    Pre-process the Susceptibility-weighted images and write out nifti files for
    feeding into PRELUDE (Phase Unwrapping Library of FSL).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        scanner: Name of the scanner (one of ge, siemens or philips).
        out_magnitude: Name of the output magnitude file after preprocessing.\
            Ensure it has a .nii suffix.
        out_phase: Name of the output phase file after preprocessing. Ensure it\
            has a .nii suffix.
        ge_file: Name of the input GE file (only compatible with --scanner ge\
            option).
        philips_file: Name of the input Philips file (only compatible with\
            --scanner philips option).
        siemens_magnitude: Name of the input Siemens magnitude file (only\
            compatible with --scanner siemens option).
        siemens_phase: Name of the input Siemens phase file (only compatible\
            with --scanner siemens option).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SwiPreprocessOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SWI_PREPROCESS_METADATA)
    cargs = []
    cargs.append("swi_preprocess")
    cargs.extend([
        "--scanner",
        scanner
    ])
    if ge_file is not None:
        cargs.extend([
            "--ge_file",
            execution.input_file(ge_file)
        ])
    if philips_file is not None:
        cargs.extend([
            "--philips_file",
            execution.input_file(philips_file)
        ])
    if siemens_magnitude is not None:
        cargs.extend([
            "--siemens_mag",
            execution.input_file(siemens_magnitude)
        ])
    if siemens_phase is not None:
        cargs.extend([
            "--siemens_phase",
            execution.input_file(siemens_phase)
        ])
    cargs.extend([
        "--out_magnitude",
        out_magnitude
    ])
    cargs.extend([
        "--out_phase",
        out_phase
    ])
    ret = SwiPreprocessOutputs(
        root=execution.output_file("."),
        output_magnitude_file=execution.output_file(out_magnitude),
        output_phase_file=execution.output_file(out_phase),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SWI_PREPROCESS_METADATA",
    "SwiPreprocessOutputs",
    "swi_preprocess",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_CVS_DATA_COPY_METADATA = Metadata(
    id="b73336351ee9c11ffda39c6ee8b2af17a54695d1.boutiques",
    name="mri_cvs_data_copy",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriCvsDataCopyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_cvs_data_copy(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_cvs_data_copy(
    subjid: str,
    olddir: str,
    newdir: str,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> MriCvsDataCopyOutputs:
    """
    Packs and copies files that are required for mri_cvs_register.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjid: Subject ID of the subject to be moved/registered.
        olddir: Directory where data (FS reconned output files for the subject)\
            is currently located. Use full path.
        newdir: Directory where data (FS reconned output files for the subject)\
            should be moved to. Use full path.
        version: Print version and exit.
        help_: Print help and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriCvsDataCopyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_CVS_DATA_COPY_METADATA)
    cargs = []
    cargs.append("mri_cvs_data_copy")
    cargs.extend([
        "--subjid",
        subjid
    ])
    cargs.extend([
        "--olddir",
        olddir
    ])
    cargs.extend([
        "--newdir",
        newdir
    ])
    if version:
        cargs.append("--version")
    if help_:
        cargs.append("--help")
    ret = MriCvsDataCopyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_CVS_DATA_COPY_METADATA",
    "MriCvsDataCopyOutputs",
    "mri_cvs_data_copy",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COMPUTE_DISTANCES_METADATA = Metadata(
    id="eb2a170cca460d6725165d5ac72cc0e8e165909c.boutiques",
    name="mri_compute_distances",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriComputeDistancesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_compute_distances(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_xform_file: OutputPathType
    """Output transformation file"""


def mri_compute_distances(
    source: InputPathType,
    target: InputPathType,
    output_xform: str,
    runner: Runner | None = None,
) -> MriComputeDistancesOutputs:
    """
    A tool to compute distances between source and target images.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source: Input source image file.
        target: Input target image file.
        output_xform: Output transformation file containing the computed\
            distances.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriComputeDistancesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COMPUTE_DISTANCES_METADATA)
    cargs = []
    cargs.append("mri_compute_distances")
    cargs.append(execution.input_file(source))
    cargs.append(execution.input_file(target))
    cargs.append(output_xform)
    ret = MriComputeDistancesOutputs(
        root=execution.output_file("."),
        output_xform_file=execution.output_file(output_xform),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COMPUTE_DISTANCES_METADATA",
    "MriComputeDistancesOutputs",
    "mri_compute_distances",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

IS_SURFACE_METADATA = Metadata(
    id="6cb9d1446618fbf43c51093ee6543e6c01436b21.boutiques",
    name="is-surface",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class IsSurfaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `is_surface(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def is_surface(
    infile: InputPathType,
    runner: Runner | None = None,
) -> IsSurfaceOutputs:
    """
    Determines whether a file is a volume-encoded surface file by examining its
    dimensions.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        infile: Input file to check if it's a surface.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `IsSurfaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(IS_SURFACE_METADATA)
    cargs = []
    cargs.extend([
        "-surface",
        "is" + execution.input_file(infile)
    ])
    ret = IsSurfaceOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "IS_SURFACE_METADATA",
    "IsSurfaceOutputs",
    "is_surface",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UNPACKSDCMDIR_METADATA = Metadata(
    id="874ca0580e83acbaad099d815a81e39d50b1ac26.boutiques",
    name="unpacksdcmdir",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class UnpacksdcmdirOutputs(typing.NamedTuple):
    """
    Output object returned when calling `unpacksdcmdir(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    unpacked_data: OutputPathType
    """The directory that will contain the unpacked data."""


def unpacksdcmdir(
    input_directory: str,
    output_directory: str,
    runner: Runner | None = None,
) -> UnpacksdcmdirOutputs:
    """
    A tool for unpacking SD card directories, typically used in neuroimaging
    workflows. It seems to have a dependency on Tcl, as indicated by the error
    messages.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_directory: The directory containing SD card data to be unpacked.
        output_directory: The output directory where unpacked data will be\
            stored.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UnpacksdcmdirOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UNPACKSDCMDIR_METADATA)
    cargs = []
    cargs.append("unpacksdcmdir")
    cargs.append(input_directory)
    cargs.append(output_directory)
    ret = UnpacksdcmdirOutputs(
        root=execution.output_file("."),
        unpacked_data=execution.output_file(output_directory + "/unpacked_data"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UNPACKSDCMDIR_METADATA",
    "UnpacksdcmdirOutputs",
    "unpacksdcmdir",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_SEGMENT_VALS_METADATA = Metadata(
    id="8fb7152be4e370cbcf1d314e781abb1f188e845e.boutiques",
    name="mris_segment_vals",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisSegmentValsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_segment_vals(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_curv: OutputPathType
    """Output w/curv file after segmentation"""


def mris_segment_vals(
    input_surface: InputPathType,
    input_curv_file: InputPathType,
    output_curv_file: str,
    threshold: float | None = None,
    area_thresh: float | None = None,
    runner: Runner | None = None,
) -> MrisSegmentValsOutputs:
    """
    This program segments an input val file into connected components.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        input_curv_file: Input w/curv file.
        output_curv_file: Output w/curv file.
        threshold: Threshold for segmentation (default is 0).
        area_thresh: Ignore segments smaller than <area thresh> mm (default 0).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisSegmentValsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_SEGMENT_VALS_METADATA)
    cargs = []
    cargs.append("mris_segment_vals")
    cargs.append(execution.input_file(input_surface))
    cargs.append(execution.input_file(input_curv_file))
    cargs.append(output_curv_file)
    if threshold is not None:
        cargs.extend([
            "-T",
            str(threshold)
        ])
    if area_thresh is not None:
        cargs.extend([
            "-A",
            str(area_thresh)
        ])
    ret = MrisSegmentValsOutputs(
        root=execution.output_file("."),
        output_curv=execution.output_file(output_curv_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_SEGMENT_VALS_METADATA",
    "MrisSegmentValsOutputs",
    "mris_segment_vals",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_UNIFIZE_METADATA = Metadata(
    id="f384aca7310e07ceca93f58ec17ea0b68b11373d.boutiques",
    name="3dUnifize",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dUnifizeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_unifize(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    out_file: OutputPathType | None
    """Output image file name."""
    scale_file_outfile: OutputPathType | None
    """Scale factor file."""


def v_3d_unifize(
    in_file: InputPathType,
    cl_frac: float | None = None,
    epi: bool = False,
    gm: bool = False,
    no_duplo: bool = False,
    num_threads: int | None = None,
    outputtype: typing.Literal["NIFTI", "AFNI", "NIFTI_GZ"] | None = None,
    quiet: bool = False,
    rbt: list[float] | None = None,
    prefix: str | None = None,
    scale_file: InputPathType | None = None,
    t2: bool = False,
    t2_up: float | None = None,
    urad: float | None = None,
    runner: Runner | None = None,
) -> V3dUnifizeOutputs:
    """
    3dUnifize - for uniformizing image intensity
    * The input dataset is supposed to be a T1-weighted volume, possibly already
    skull-stripped (e.g., via 3dSkullStrip). However, this program can be a
    useful step to take BEFORE 3dSkullStrip, since the latter program can fail
    if the input volume is strongly shaded -- 3dUnifize will (mostly) remove
    such shading artifacts.
    * The output dataset has the white matter (WM) intensity approximately
    uniformized across space, and scaled to peak at about 1000.
    * The output dataset is always stored in float format!
    * If the input dataset has more than 1 sub-brick, only sub-brick #0 will be
    processed!
    * Want to correct EPI datasets for nonuniformity? You can try the new and
    experimental [Mar 2017] '-EPI' option.
    * The principal motive for this program is for use in an image registration
    script, and it may or may not be useful otherwise.
    * This program replaces the older (and very different) 3dUniformize, which
    is no longer maintained and may sublimate at any moment. (In other words, we
    do not recommend the use of 3dUniformize.).
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_file: Input file to 3dunifize.
        cl_frac: Option for afni experts only.set the automask 'clip level\
            fraction'. must be between 0.1 and 0.9. a small fraction means to make\
            the initial threshold for clipping (a la 3dcliplevel) smaller, which\
            will tend to make the mask larger. [default=0.1].
        epi: Assume the input dataset is a t2 (or t2\\*) weighted epi time\
            series. after computing the scaling, apply it to all volumes (trs) in\
            the input dataset. that is, a given voxel will be scaled by the same\
            factor at each tr. this option also implies '-noduplo' and '-t2'.this\
            option turns off '-gm' if you turned it on.
        gm: Also scale to unifize 'gray matter' = lower intensity voxels (to\
            aid in registering images from different scanners).
        no_duplo: Do not use the 'duplo down' step; this can be useful for\
            lower resolution datasets.
        num_threads: Set number of threads.
        outputtype: 'nifti' or 'afni' or 'nifti_gz'. Afni output filetype.
        quiet: Don't print the progress messages.
        rbt: (a float, a float, a float). Option for afni experts only.specify\
            the 3 parameters for the algorithm:r = radius; same as given by option\
            '-urad', [default=18.3]b = bottom percentile of normalizing data range,\
            [default=70.0]r = top percentile of normalizing data range,\
            [default=80.0].
        prefix: Output image file name.
        scale_file: Output file name to save the scale factor used at each\
            voxel .
        t2: Treat the input as if it were t2-weighted, rather than t1-weighted.\
            this processing is done simply by inverting the image contrast,\
            processing it as if that result were t1-weighted, and then re-inverting\
            the results counts of voxel overlap, i.e., each voxel will contain the\
            number of masks that it is set in.
        t2_up: Option for afni experts only.set the upper percentile point used\
            for t2-t1 inversion. allowed to be anything between 90 and 100\
            (inclusive), with default to 98.5 (for no good reason).
        urad: Sets the radius (in voxels) of the ball used for the sneaky\
            trick. default value is 18.3, and should be changed proportionally if\
            the dataset voxel size differs significantly from 1 mm.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dUnifizeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_UNIFIZE_METADATA)
    cargs = []
    cargs.append("3dUnifize")
    if cl_frac is not None:
        cargs.extend([
            "-clfrac",
            str(cl_frac)
        ])
    if epi:
        cargs.append("-EPI")
    if gm:
        cargs.append("-GM")
    if no_duplo:
        cargs.append("-noduplo")
    if num_threads is not None:
        cargs.append(str(num_threads))
    if outputtype is not None:
        cargs.append(outputtype)
    if quiet:
        cargs.append("-quiet")
    if rbt is not None:
        cargs.extend([
            "-rbt",
            *map(str, rbt)
        ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if scale_file is not None:
        cargs.extend([
            "-ssave",
            execution.input_file(scale_file)
        ])
    if t2:
        cargs.append("-T2")
    if t2_up is not None:
        cargs.extend([
            "-T2up",
            str(t2_up)
        ])
    if urad is not None:
        cargs.extend([
            "-Urad",
            str(urad)
        ])
    cargs.extend([
        "-input",
        execution.input_file(in_file)
    ])
    ret = V3dUnifizeOutputs(
        root=execution.output_file("."),
        out_file=execution.output_file(prefix) if (prefix is not None) else None,
        scale_file_outfile=execution.output_file(pathlib.Path(scale_file).name) if (scale_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dUnifizeOutputs",
    "V_3D_UNIFIZE_METADATA",
    "v_3d_unifize",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_INFO_METADATA = Metadata(
    id="f8473bd4b6a90f8c8b3dbe8a7c1e45f9016b4d73.boutiques",
    name="mris_info",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType | None
    """Output file containing saved data"""
    output_edge_file: OutputPathType | None
    """File containing edge info"""


def mris_info(
    surfacefile: InputPathType,
    outfile: InputPathType | None = None,
    subject_hemi_surfname: str | None = None,
    patchfile: InputPathType | None = None,
    vertex_number: float | None = None,
    extended_vertex_number: float | None = None,
    curvfile: InputPathType | None = None,
    annotfile: InputPathType | None = None,
    edge_stats_id: str | None = None,
    edge_number: float | None = None,
    vtxno: str | None = None,
    matrix_format: str | None = None,
    mask_file: InputPathType | None = None,
    label_file: InputPathType | None = None,
    edge_file: InputPathType | None = None,
    talairach_xfm_flag: bool = False,
    rescale_flag: bool = False,
    area_stats_flag: bool = False,
    quality_stats_flag: bool = False,
    intersections_flag: bool = False,
    nogifti_flag: bool = False,
    version_flag: bool = False,
    help_flag: bool = False,
    runner: Runner | None = None,
) -> MrisInfoOutputs:
    """
    Prints out information about a surface file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surfacefile: Surface file to process.
        outfile: Save some data to outfile.
        subject_hemi_surfname: Instead of surfacefile.
        patchfile: Load patch before reporting.
        vertex_number: Print out vertex information for vertex vnum.
        extended_vertex_number: Print out extended vertex information for\
            vertex vnum.
        curvfile: Check if curvature file vertices match surface vertices.
        annotfile: Check if annotation file vertices match surface vertices;\
            dump colortable.
        edge_stats_id: Compute stats on edge metric (n, mean, std, min, max);\
            id=0=length, id=1=dot, id=2=angle, id<0= all.
        edge_number: Print out extended information about edge.
        vtxno: Write Matlab file to plot vertex neighborhood.
        matrix_format: Set format for matrix printing (e.g., %12.8f).
        mask_file: Only compute edge and area stats using vertices in mask.
        label_file: Only compute edge and area stats using vertices in label.
        edge_file: Print edge info for all edges into file.
        talairach_xfm_flag: Apply talairach xfm before reporting info.
        rescale_flag: Rescale group surface to match average metrics.
        area_stats_flag: Compute stats on triangle area (n, mean, std, min,\
            max).
        quality_stats_flag: Print out surface quality stats.
        intersections_flag: Print the number of vertices that belong to a face\
            that intersects another face.
        nogifti_flag: No dump of GIFTI struct, read .gii as surface instead.
        version_flag: Print version and exits.
        help_flag: No clue what this does.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisInfoOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_INFO_METADATA)
    cargs = []
    cargs.append("mris_info")
    cargs.append(execution.input_file(surfacefile))
    if outfile is not None:
        cargs.extend([
            "--o",
            execution.input_file(outfile)
        ])
    if subject_hemi_surfname is not None:
        cargs.extend([
            "--s",
            subject_hemi_surfname
        ])
    if patchfile is not None:
        cargs.extend([
            "--patch",
            execution.input_file(patchfile)
        ])
    if vertex_number is not None:
        cargs.extend([
            "--v",
            str(vertex_number)
        ])
    if extended_vertex_number is not None:
        cargs.extend([
            "--vx",
            str(extended_vertex_number)
        ])
    if curvfile is not None:
        cargs.extend([
            "--c",
            execution.input_file(curvfile)
        ])
    if annotfile is not None:
        cargs.extend([
            "--a",
            execution.input_file(annotfile)
        ])
    if edge_stats_id is not None:
        cargs.extend([
            "--edge-stats",
            edge_stats_id
        ])
    if edge_number is not None:
        cargs.extend([
            "--ex",
            str(edge_number)
        ])
    if vtxno is not None:
        cargs.extend([
            "--v-matlab",
            vtxno
        ])
    if matrix_format is not None:
        cargs.extend([
            "--mtx-fmt",
            matrix_format
        ])
    if mask_file is not None:
        cargs.extend([
            "--mask",
            execution.input_file(mask_file)
        ])
    if label_file is not None:
        cargs.extend([
            "--label",
            execution.input_file(label_file)
        ])
    if edge_file is not None:
        cargs.extend([
            "--edge-file",
            execution.input_file(edge_file)
        ])
    if talairach_xfm_flag:
        cargs.append("--t")
    if rescale_flag:
        cargs.append("--r")
    if area_stats_flag:
        cargs.append("--area-stats")
    cargs.append("[EDGE_STATS_FLAG]")
    if quality_stats_flag:
        cargs.append("--quality")
    if intersections_flag:
        cargs.append("--intersections")
    if nogifti_flag:
        cargs.append("--nogifti-disp-image")
    if version_flag:
        cargs.append("--version")
    if help_flag:
        cargs.append("--help")
    ret = MrisInfoOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(pathlib.Path(outfile).name) if (outfile is not None) else None,
        output_edge_file=execution.output_file(pathlib.Path(edge_file).name) if (edge_file is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_INFO_METADATA",
    "MrisInfoOutputs",
    "mris_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RCA_CONFIG_METADATA = Metadata(
    id="51c0aae9a34d0b770555399cc01f066ce00769c7.boutiques",
    name="rca-config",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RcaConfigOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rca_config(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rca_config(
    source_config: InputPathType,
    updated_config: InputPathType,
    unknown_args_file: InputPathType,
    args: list[str] | None = None,
    runner: Runner | None = None,
) -> RcaConfigOutputs:
    """
    A command-line tool that processes configuration files and arguments.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        source_config: Path to the source configuration file.
        updated_config: Path to the updated configuration file.
        unknown_args_file: Path to the file where unknown arguments are\
            recorded.
        args: Additional arguments to be processed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RcaConfigOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RCA_CONFIG_METADATA)
    cargs = []
    cargs.extend([
        "-config",
        "recon" + execution.input_file(source_config)
    ])
    cargs.append(execution.input_file(updated_config))
    cargs.append(execution.input_file(unknown_args_file))
    if args is not None:
        cargs.extend(args)
    ret = RcaConfigOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RCA_CONFIG_METADATA",
    "RcaConfigOutputs",
    "rca_config",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DCMDRLE_FS_METADATA = Metadata(
    id="1c6fdec3b4ee16a344e1e0d5d4e1bcbc79b17f47.boutiques",
    name="dcmdrle.fs",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DcmdrleFsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dcmdrle_fs(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output DICOM file."""


def dcmdrle_fs(
    input_file: InputPathType,
    output_file: str,
    help_: bool = False,
    version: bool = False,
    arguments: bool = False,
    quiet: bool = False,
    verbose: bool = False,
    debug: bool = False,
    log_level: str | None = None,
    log_config: InputPathType | None = None,
    read_file: bool = False,
    read_file_only: bool = False,
    read_dataset: bool = False,
    uid_default: bool = False,
    uid_always: bool = False,
    byte_order_default: bool = False,
    byte_order_reverse: bool = False,
    write_file: bool = False,
    write_dataset: bool = False,
    write_xfer_little: bool = False,
    write_xfer_big: bool = False,
    write_xfer_implicit: bool = False,
    enable_new_vr: bool = False,
    disable_new_vr: bool = False,
    group_length_recalc: bool = False,
    group_length_create: bool = False,
    group_length_remove: bool = False,
    length_explicit: bool = False,
    length_undefined: bool = False,
    padding_retain: bool = False,
    padding_off: bool = False,
    padding_create: str | None = None,
    runner: Runner | None = None,
) -> DcmdrleFsOutputs:
    """
    Decodes RLE-compressed DICOM files.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: DICOM input filename to be converted.
        output_file: DICOM output filename.
        help_: Print help text and exit.
        version: Print version information and exit.
        arguments: Print expanded command line arguments.
        quiet: Quiet mode, print no warnings and errors.
        verbose: Verbose mode, print processing details.
        debug: Debug mode, print debug information.
        log_level: Set logger level.
        log_config: Use config file for the logger.
        read_file: Read file format or data set (default).
        read_file_only: Read file format only.
        read_dataset: Read data set without file meta information.
        uid_default: Keep same SOP Instance UID (default).
        uid_always: Always assign new UID.
        byte_order_default: Most significant byte first (default).
        byte_order_reverse: Least significant byte first.
        write_file: Write file format (default).
        write_dataset: Write data set without file meta information.
        write_xfer_little: Write with explicit VR little endian (default).
        write_xfer_big: Write with explicit VR big endian TS.
        write_xfer_implicit: Write with implicit VR little endian TS.
        enable_new_vr: Enable support for new VRs (UN/UT) (default).
        disable_new_vr: Disable support for new VRs, convert to OB.
        group_length_recalc: Recalculate group lengths if present (default).
        group_length_create: Always write with group length elements.
        group_length_remove: Always write without group length elements.
        length_explicit: Write with explicit lengths (default).
        length_undefined: Write with undefined lengths.
        padding_retain: Do not change padding.
        padding_off: No padding (implicit if --write-dataset).
        padding_create: Align file on multiple of file-pad bytes and items on\
            multiple of item-pad bytes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DcmdrleFsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DCMDRLE_FS_METADATA)
    cargs = []
    cargs.append("dcmdrle")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    if help_:
        cargs.append("-h")
    if version:
        cargs.append("--version")
    if arguments:
        cargs.append("--arguments")
    if quiet:
        cargs.append("-q")
    if verbose:
        cargs.append("-v")
    if debug:
        cargs.append("-d")
    if log_level is not None:
        cargs.extend([
            "-ll",
            log_level
        ])
    if log_config is not None:
        cargs.extend([
            "-lc",
            execution.input_file(log_config)
        ])
    if read_file:
        cargs.append("+f")
    if read_file_only:
        cargs.append("+fo")
    if read_dataset:
        cargs.append("-f")
    if uid_default:
        cargs.append("+ud")
    if uid_always:
        cargs.append("+ua")
    if byte_order_default:
        cargs.append("+bd")
    if byte_order_reverse:
        cargs.append("+br")
    if write_file:
        cargs.append("+F")
    if write_dataset:
        cargs.append("-F")
    if write_xfer_little:
        cargs.append("+te")
    if write_xfer_big:
        cargs.append("+tb")
    if write_xfer_implicit:
        cargs.append("+ti")
    if enable_new_vr:
        cargs.append("+u")
    if disable_new_vr:
        cargs.append("-u")
    if group_length_recalc:
        cargs.append("+g=")
    if group_length_create:
        cargs.append("+g")
    if group_length_remove:
        cargs.append("-g")
    if length_explicit:
        cargs.append("+e")
    if length_undefined:
        cargs.append("-e")
    if padding_retain:
        cargs.append("-p=")
    if padding_off:
        cargs.append("-p")
    if padding_create is not None:
        cargs.extend([
            "+p",
            padding_create
        ])
    ret = DcmdrleFsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DCMDRLE_FS_METADATA",
    "DcmdrleFsOutputs",
    "dcmdrle_fs",
]



"""
MRTrix3Tissue

MRtrix3Tissue is a fork of the MRtrix3 project. It aims to add capabilities for
3-Tissue CSD modelling and analysis to a complete version of the MRtrix3
software.

URL: https://3tissue.github.io/
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .ss3t_csd_beta1 import *



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MNI152REG_METADATA = Metadata(
    id="ce57b863d24379ba72442d213f0a02c5cba44366.boutiques",
    name="mni152reg",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Mni152regOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mni152reg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reg_matrix_2mm: OutputPathType
    """Output registration matrix for standard 2mm target"""
    reg_matrix_1mm: OutputPathType
    """Output registration matrix for 1mm target when --1 flag is used"""


def mni152reg(
    subject: str,
    register_1mm: bool = False,
    output: str | None = None,
    symmetric: bool = False,
    save_volume: bool = False,
    runner: Runner | None = None,
) -> Mni152regOutputs:
    """
    Registers the FreeSurfer subject to the FSL MNI 152 brain to create a
    tkregister-style registration matrix.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject: FreeSurfer subject ID.
        register_1mm: Register to 1mm target (instead of 2mm).
        output: Explicitly set output registration file.
        symmetric: Register to FSL symmetric target.
        save_volume: Sample original to output space.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Mni152regOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MNI152REG_METADATA)
    cargs = []
    cargs.append("mni152reg")
    cargs.extend([
        "-s",
        "-" + subject
    ])
    if register_1mm:
        cargs.append("--1")
    if output is not None:
        cargs.extend([
            "--o",
            output
        ])
    if symmetric:
        cargs.append("--sym")
    if save_volume:
        cargs.append("--save-vol")
    ret = Mni152regOutputs(
        root=execution.output_file("."),
        reg_matrix_2mm=execution.output_file("$SUBJECTS_DIR/" + subject + "/mri/transforms/reg.mni152.2mm.dat"),
        reg_matrix_1mm=execution.output_file("$SUBJECTS_DIR/" + subject + "/mri/transforms/reg.mni152.1mm.dat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MNI152REG_METADATA",
    "Mni152regOutputs",
    "mni152reg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__GRAYPLOT_METADATA = Metadata(
    id="3d444976676cbb4979c872f1285979b9e0bd687d.boutiques",
    name="@grayplot",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VGrayplotOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__grayplot(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    grayplot_img: OutputPathType
    """Output grayplot image"""


def v__grayplot(
    dirname: str,
    allorder: bool = False,
    runner: Runner | None = None,
) -> VGrayplotOutputs:
    """
    Script to read files from an afni_proc.py results directory and produce a
    grayplot from the errts dataset(s), combined with a motion magnitude indicator
    graph.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dirname: Directory containing afni_proc.py results.
        allorder: Create grayplots for all ordering methods.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VGrayplotOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__GRAYPLOT_METADATA)
    cargs = []
    cargs.append("@grayplot")
    cargs.append(dirname)
    if allorder:
        cargs.append("-ALLorder")
    ret = VGrayplotOutputs(
        root=execution.output_file("."),
        grayplot_img=execution.output_file("Grayplot.errts.*.png"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VGrayplotOutputs",
    "V__GRAYPLOT_METADATA",
    "v__grayplot",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SAMSEG_LONG_METADATA = Metadata(
    id="686e2f45cf8bcf8f37552255f101cc1d16f93f40.boutiques",
    name="samseg-long",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class SamsegLongOutputs(typing.NamedTuple):
    """
    Output object returned when calling `samseg_long(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    tp001_output: OutputPathType
    """Samseg output folder for the first time point."""
    tp002_output: OutputPathType
    """Samseg output folder for the second time point."""
    base_output: OutputPathType
    """Base folder created by the samseg-long process."""


def samseg_long(
    output_dir: str,
    input_files: list[InputPathType],
    align_no_mc: bool = False,
    threads: float | None = None,
    save_posteriors: bool = False,
    force_update: bool = False,
    runner: Runner | None = None,
) -> SamsegLongOutputs:
    """
    Longitudinal analysis tool using SAMSEG in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_dir: Output directory.
        input_files: Input image files. All inputs must be a single modality.
        align_no_mc: Do not align inputs using robust register.
        threads: Number of threads to use.
        save_posteriors: Save posterior probabilities.
        force_update: Force update of outputs.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SamsegLongOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SAMSEG_LONG_METADATA)
    cargs = []
    cargs.append("samseg-long")
    cargs.extend([
        "--o",
        output_dir
    ])
    if align_no_mc:
        cargs.append("--no-mc")
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    cargs.extend([
        "--i",
        *[execution.input_file(f) for f in input_files]
    ])
    if save_posteriors:
        cargs.append("--save-posteriors")
    if force_update:
        cargs.append("--force-update")
    ret = SamsegLongOutputs(
        root=execution.output_file("."),
        tp001_output=execution.output_file(output_dir + "/tp001"),
        tp002_output=execution.output_file(output_dir + "/tp002"),
        base_output=execution.output_file(output_dir + "/base"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SAMSEG_LONG_METADATA",
    "SamsegLongOutputs",
    "samseg_long",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG_JACOBIAN_METADATA = Metadata(
    id="d9f34948bab197070a574d5681291e414546dcaa.boutiques",
    name="reg_jacobian",
    package="niftyreg",
    container_image_tag="vnmd/niftyreg_1.4.0:20220819",
)


class RegJacobianOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg_jacobian(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_jacobian_file: OutputPathType | None
    """File containing the Jacobian determinant map"""
    output_jacobian_matrix_file: OutputPathType | None
    """File containing the Jacobian matrix map"""
    output_log_jacobian_file: OutputPathType | None
    """File containing the log of the Jacobian determinant map"""


def reg_jacobian(
    reference_image: InputPathType,
    deformation_field: InputPathType | None = None,
    control_point_lattice: InputPathType | None = None,
    output_jacobian: str | None = None,
    output_jacobian_matrix: str | None = None,
    output_log_jacobian: str | None = None,
    affine_matrix: InputPathType | None = None,
    runner: Runner | None = None,
) -> RegJacobianOutputs:
    """
    Tool to compute the Jacobian determinant map from a deformation field or control
    point lattice.
    
    Author: NiftyReg Developers
    
    URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
    
    Args:
        reference_image: Filename of the reference image.
        deformation_field: Filename of the deformation field (from\
            reg_transform).
        control_point_lattice: Filename of the control point position lattice\
            (from reg_f3d).
        output_jacobian: Filename of the Jacobian determinant map.
        output_jacobian_matrix: Filename of the Jacobian matrix map (9 or 4\
            values stored as a 5D nifti).
        output_log_jacobian: Filename of the Log of the Jacobian determinant\
            map.
        affine_matrix: Filename of the affine matrix to modulate the Jacobian\
            determinant map.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegJacobianOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG_JACOBIAN_METADATA)
    cargs = []
    cargs.append("reg_jacobian")
    cargs.extend([
        "-ref",
        execution.input_file(reference_image)
    ])
    if deformation_field is not None:
        cargs.extend([
            "-def",
            execution.input_file(deformation_field)
        ])
    if control_point_lattice is not None:
        cargs.extend([
            "-cpp",
            execution.input_file(control_point_lattice)
        ])
    if output_jacobian is not None:
        cargs.extend([
            "-jac",
            output_jacobian
        ])
    if output_jacobian_matrix is not None:
        cargs.extend([
            "-jacM",
            output_jacobian_matrix
        ])
    if output_log_jacobian is not None:
        cargs.extend([
            "-jacL",
            output_log_jacobian
        ])
    if affine_matrix is not None:
        cargs.extend([
            "-aff",
            execution.input_file(affine_matrix)
        ])
    ret = RegJacobianOutputs(
        root=execution.output_file("."),
        output_jacobian_file=execution.output_file(output_jacobian) if (output_jacobian is not None) else None,
        output_jacobian_matrix_file=execution.output_file(output_jacobian_matrix) if (output_jacobian_matrix is not None) else None,
        output_log_jacobian_file=execution.output_file(output_log_jacobian) if (output_log_jacobian is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG_JACOBIAN_METADATA",
    "RegJacobianOutputs",
    "reg_jacobian",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_ROW_FILLIN_METADATA = Metadata(
    id="efdbcc5556b9f847fe0eba3e015856a0addd50be.boutiques",
    name="3dRowFillin",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dRowFillinOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_row_fillin(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_brik: OutputPathType | None
    """Output dataset in BRIK format"""
    output_head: OutputPathType | None
    """Output dataset in HEAD format"""


def v_3d_row_fillin(
    input_dataset: InputPathType,
    maxgap: float | None = None,
    dir_: str | None = None,
    binary: bool = False,
    prefix: str | None = None,
    runner: Runner | None = None,
) -> V3dRowFillinOutputs:
    """
    Fills in blank regions in 1D rows extracted from a 3D dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input 3D dataset (e.g., dataset+orig).
        maxgap: Set the maximum length of a blank region that will be filled in.
        dir_: Set the direction of fill, e.g., A-P, P-A, I-S, S-I, L-R, R-L, x,\
            y, z, XYZ.OR, XYZ.AND.
        binary: Turn input dataset to binary (0 and 1) before filling in.\
            Output will also be binary.
        prefix: Set the prefix for the output dataset.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dRowFillinOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_ROW_FILLIN_METADATA)
    cargs = []
    cargs.append("3dRowFillin")
    if maxgap is not None:
        cargs.extend([
            "-maxgap",
            str(maxgap)
        ])
    if dir_ is not None:
        cargs.extend([
            "-dir",
            dir_
        ])
    if binary:
        cargs.append("-binary")
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    cargs.append(execution.input_file(input_dataset))
    ret = V3dRowFillinOutputs(
        root=execution.output_file("."),
        output_brik=execution.output_file(prefix + "+orig.BRIK") if (prefix is not None) else None,
        output_head=execution.output_file(prefix + "+orig.HEAD") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dRowFillinOutputs",
    "V_3D_ROW_FILLIN_METADATA",
    "v_3d_row_fillin",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

BETSURF_METADATA = Metadata(
    id="7a094f934968097bde54d5a6fbea512011c9f723.boutiques",
    name="betsurf",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class BetsurfOutputs(typing.NamedTuple):
    """
    Output object returned when calling `betsurf(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_mask: OutputPathType
    """Generated binary mask"""
    output_outline: OutputPathType
    """Generated surface outline"""
    output_skull: OutputPathType
    """Generated skull mask"""


def betsurf(
    t1_image: InputPathType,
    bet_mesh: InputPathType,
    t1_to_standard_mat: InputPathType,
    output_prefix: str,
    t2_image: InputPathType | None = None,
    help_flag: bool = False,
    verbose_flag: bool = False,
    t1only_flag: bool = False,
    outline_flag: bool = False,
    mask_flag: bool = False,
    skull_mask_flag: bool = False,
    increased_precision: int | None = None,
    runner: Runner | None = None,
) -> BetsurfOutputs:
    """
    BET Surface Finder to extract brain surfaces using T1 and T2 images.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        t1_image: T1-weighted MRI image.
        bet_mesh: BET Mesh File (.vtk).
        t1_to_standard_mat: Transformation matrix file from T1 to standard\
            space.
        output_prefix: Output prefix for generated files.
        t2_image: T2-weighted MRI image (optional if using --t1only flag).
        help_flag: Displays help message and exits.
        verbose_flag: Switch on diagnostic messages.
        t1only_flag: Extraction with T1 only.
        outline_flag: Generates all surface outlines.
        mask_flag: Generates binary masks from the meshes.
        skull_mask_flag: Generates skull binary mask.
        increased_precision: Retessellates the meshes the indicated number of\
            times (int).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `BetsurfOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(BETSURF_METADATA)
    cargs = []
    cargs.append("betsurf")
    cargs.append(execution.input_file(t1_image))
    if t2_image is not None:
        cargs.append(execution.input_file(t2_image))
    cargs.append(execution.input_file(bet_mesh))
    cargs.append(execution.input_file(t1_to_standard_mat))
    cargs.append(output_prefix)
    if help_flag:
        cargs.append("-h")
    if verbose_flag:
        cargs.append("-v")
    if t1only_flag:
        cargs.append("-1")
    if outline_flag:
        cargs.append("-o")
    if mask_flag:
        cargs.append("-m")
    if skull_mask_flag:
        cargs.append("-s")
    if increased_precision is not None:
        cargs.extend([
            "-p",
            str(increased_precision)
        ])
    ret = BetsurfOutputs(
        root=execution.output_file("."),
        output_mask=execution.output_file(output_prefix + "_mask.nii.gz"),
        output_outline=execution.output_file(output_prefix + "_outline.nii.gz"),
        output_skull=execution.output_file(output_prefix + "_skull.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "BETSURF_METADATA",
    "BetsurfOutputs",
    "betsurf",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_RIGID_REGISTER_METADATA = Metadata(
    id="86ae5f77c79298b854bf775bed382049d793e4ae.boutiques",
    name="fsl_rigid_register",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class FslRigidRegisterOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_rigid_register(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fslmat_output: OutputPathType
    """The registration matrix in FSL format."""


def fsl_rigid_register(
    refvol: InputPathType,
    inputvol: InputPathType,
    outputvol: str,
    fslmat: str | None = None,
    regmat: str | None = None,
    xfmmat: str | None = None,
    ltamat: str | None = None,
    noinitgeom: bool = False,
    applyxfm: InputPathType | None = None,
    applyinitxfm: bool = False,
    initxfm: InputPathType | None = None,
    maxangle: float | None = None,
    interp: str | None = None,
    dof: float | None = None,
    bins: float | None = None,
    cost: str | None = None,
    tmpdir: str | None = None,
    nocleanup: bool = False,
    cleanup: bool = False,
    subject: str | None = None,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> FslRigidRegisterOutputs:
    """
    A front-end tool for FSL's FLIRT that computes a rigid registration matrix and
    resamples the input volume to the reference volume.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        refvol: Reference/Target volume.
        inputvol: Input/Moveable volume.
        outputvol: Input resampled to reference.
        fslmat: Specifies explicitly where to store the FSL registration\
            matrix.
        regmat: Get registration matrix in register.dat file format.
        xfmmat: Get registration matrix as MNI xfm file.
        ltamat: Get registration matrix as MGH lta file.
        noinitgeom: Do not initialize matrix based on geometry.
        applyxfm: Apply a transformation file to the input without\
            registration.
        applyinitxfm: Apply initial transformation to the input without\
            registration.
        initxfm: Use this as an initial matrix for registration.
        maxangle: Only search over +/- max angle degrees.
        interp: Interpolation method: trilinear, nearestneighbour, sinc.
        dof: Use degrees of freedom instead of 6.
        bins: Number of bins to use (default 256).
        cost: Objective function: mutualinfo, corratio (default), normcorr,\
            normmi, leastsq.
        tmpdir: Specify temporary directory.
        nocleanup: Do not delete temporary files.
        cleanup: Delete temporary files (default).
        subject: Only puts it in the register.dat file.
        version: Print version and exit.
        help_: Print help and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslRigidRegisterOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_RIGID_REGISTER_METADATA)
    cargs = []
    cargs.append("fsl_rigid_register")
    cargs.extend([
        "-r",
        execution.input_file(refvol)
    ])
    cargs.extend([
        "-i",
        execution.input_file(inputvol)
    ])
    cargs.extend([
        "-o",
        outputvol
    ])
    if fslmat is not None:
        cargs.extend([
            "-fslmat",
            fslmat
        ])
    if regmat is not None:
        cargs.extend([
            "-regmat",
            regmat
        ])
    if xfmmat is not None:
        cargs.extend([
            "-xfmmat",
            xfmmat
        ])
    if ltamat is not None:
        cargs.extend([
            "-ltamat",
            ltamat
        ])
    if noinitgeom:
        cargs.append("-noinitgeom")
    if applyxfm is not None:
        cargs.extend([
            "-applyxfm",
            execution.input_file(applyxfm)
        ])
    if applyinitxfm:
        cargs.append("-applyinitxfm")
    if initxfm is not None:
        cargs.extend([
            "-initxfm",
            execution.input_file(initxfm)
        ])
    if maxangle is not None:
        cargs.extend([
            "-maxangle",
            str(maxangle)
        ])
    if interp is not None:
        cargs.extend([
            "-interp",
            interp
        ])
    if dof is not None:
        cargs.extend([
            "-dof",
            str(dof)
        ])
    if bins is not None:
        cargs.extend([
            "-bins",
            str(bins)
        ])
    if cost is not None:
        cargs.extend([
            "-cost",
            cost
        ])
    if tmpdir is not None:
        cargs.extend([
            "-tmpdir",
            tmpdir
        ])
    if nocleanup:
        cargs.append("-nocleanup")
    if cleanup:
        cargs.append("-cleanup")
    if subject is not None:
        cargs.extend([
            "-subject",
            subject
        ])
    if version:
        cargs.append("-version")
    if help_:
        cargs.append("-help")
    ret = FslRigidRegisterOutputs(
        root=execution.output_file("."),
        fslmat_output=execution.output_file(outputvol + ".fslmat"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_RIGID_REGISTER_METADATA",
    "FslRigidRegisterOutputs",
    "fsl_rigid_register",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

EXTRACT_REGION_FROM_IMAGE_METADATA = Metadata(
    id="ae946f4d1bb246c4c0e1a26e1d18d3d6f5ce930d.boutiques",
    name="ExtractRegionFromImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


@dataclasses.dataclass
class ExtractRegionFromImageRegionMinMaxIndex:
    min_index: str
    """Minimum index to define the starting point of the region."""
    max_index: str
    """Maximum index to define the endpoint of the region."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.min_index)
        cargs.append(self.max_index)
        return cargs


@dataclasses.dataclass
class ExtractRegionFromImageRegionLabel:
    label: str
    """Label value to extract the region corresponding to the specified
    label."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.label)
        return cargs


@dataclasses.dataclass
class ExtractRegionFromImageRegionDomainImage:
    domain_image: InputPathType
    """Image defining the domain from which to extract the region."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(execution.input_file(self.domain_image))
        return cargs


@dataclasses.dataclass
class ExtractRegionFromImageRegionLabelWithImage:
    label: str
    """Label value used for the region extraction."""
    label_image: InputPathType
    """Image containing label information."""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append(self.label)
        cargs.append(execution.input_file(self.label_image))
        cargs.append("1")
        return cargs


class ExtractRegionFromImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `extract_region_from_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image_file: OutputPathType
    """File containing the extracted region."""


def extract_region_from_image(
    image_dimension: int,
    input_image: InputPathType,
    output_image: str,
    region_specification: typing.Union[ExtractRegionFromImageRegionMinMaxIndex, ExtractRegionFromImageRegionLabel, ExtractRegionFromImageRegionDomainImage, ExtractRegionFromImageRegionLabelWithImage],
    runner: Runner | None = None,
) -> ExtractRegionFromImageOutputs:
    """
    ExtractRegionFromImage can be used to extract a specific region from a given
    image. The region can be specified via indices, label, or another domain image.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        image_dimension: The dimensionality of the image.
        input_image: Path to the input image from which the region will be\
            extracted.
        output_image: Path to the output image where the extracted region will\
            be saved.
        region_specification: Specify the region to extract using indices,\
            label, domain image, or label with label image.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ExtractRegionFromImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(EXTRACT_REGION_FROM_IMAGE_METADATA)
    cargs = []
    cargs.append("ExtractRegionFromImage")
    cargs.append(str(image_dimension))
    cargs.append(execution.input_file(input_image))
    cargs.append(output_image)
    cargs.extend(region_specification.run(execution))
    ret = ExtractRegionFromImageOutputs(
        root=execution.output_file("."),
        output_image_file=execution.output_file(output_image),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "EXTRACT_REGION_FROM_IMAGE_METADATA",
    "ExtractRegionFromImageOutputs",
    "ExtractRegionFromImageRegionDomainImage",
    "ExtractRegionFromImageRegionLabel",
    "ExtractRegionFromImageRegionLabelWithImage",
    "ExtractRegionFromImageRegionMinMaxIndex",
    "extract_region_from_image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_TARGET_POS_METADATA = Metadata(
    id="8a1f7e5c9eef8b24a14e229ba9fabf1762b4bc4f.boutiques",
    name="mris_target_pos",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisTargetPosOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_target_pos(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mris_target_pos(
    input_volume: InputPathType,
    input_surface: InputPathType,
    output_surface: str,
    adgws_file: str,
    threshold_values: list[float] | None = None,
    label: str | None = None,
    interpolation_method: str | None = None,
    debug_vertex: float | None = None,
    cbv_flag: bool = False,
    debug_flag: bool = False,
    check_options: bool = False,
    help_flag: bool = False,
    version_flag: bool = False,
    runner: Runner | None = None,
) -> MrisTargetPosOutputs:
    """
    Tool for setting target positions of a surface using input imaging data and
    other parameters.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_volume: Input volume file.
        input_surface: Input surface file.
        output_surface: Output surface file.
        adgws_file: ADGWS file.
        threshold_values: Threshold values for inward and outward target\
            positions.
        label: Label for processing.
        interpolation_method: Interpolation method name.
        debug_vertex: Vertex number for debugging.
        cbv_flag: CBV flag.
        debug_flag: Turn on debugging.
        check_options: Check options without running the program.
        help_flag: Display help information.
        version_flag: Display version information and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTargetPosOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TARGET_POS_METADATA)
    cargs = []
    cargs.append("mris_target_pos")
    cargs.extend([
        "--v",
        execution.input_file(input_volume)
    ])
    cargs.extend([
        "--i",
        execution.input_file(input_surface)
    ])
    cargs.extend([
        "--o",
        output_surface
    ])
    cargs.extend([
        "--adgws",
        adgws_file
    ])
    if threshold_values is not None:
        cargs.extend([
            "--thresh",
            *map(str, threshold_values)
        ])
    if label is not None:
        cargs.extend([
            "--l",
            label
        ])
    if interpolation_method is not None:
        cargs.extend([
            "--interp",
            interpolation_method
        ])
    if debug_vertex is not None:
        cargs.extend([
            "--debug-vertex",
            str(debug_vertex)
        ])
    if cbv_flag:
        cargs.append("--cbv")
    if debug_flag:
        cargs.append("--debug")
    if check_options:
        cargs.append("--checkopts")
    if help_flag:
        cargs.append("--help")
    if version_flag:
        cargs.append("--version")
    ret = MrisTargetPosOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_TARGET_POS_METADATA",
    "MrisTargetPosOutputs",
    "mris_target_pos",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__CHECK_FOR_AFNI_DSET_METADATA = Metadata(
    id="36d93d7fee0a8f5033359b79ea1fc2a9f56b9766.boutiques",
    name="@CheckForAfniDset",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VCheckForAfniDsetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__check_for_afni_dset(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_status: OutputPathType
    """Text file containing the status code of the dataset"""


def v__check_for_afni_dset(
    dataset_name: str,
    runner: Runner | None = None,
) -> VCheckForAfniDsetOutputs:
    """
    Check for the existence of AFNI datasets.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        dataset_name: Path to the AFNI dataset (e.g.,\
            /Data/stuff/Hello+orig.HEAD).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VCheckForAfniDsetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__CHECK_FOR_AFNI_DSET_METADATA)
    cargs = []
    cargs.append("@CheckForAfniDset")
    cargs.append(dataset_name)
    ret = VCheckForAfniDsetOutputs(
        root=execution.output_file("."),
        output_status=execution.output_file(dataset_name + "_status.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VCheckForAfniDsetOutputs",
    "V__CHECK_FOR_AFNI_DSET_METADATA",
    "v__check_for_afni_dset",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

QUANTIFY_THALAMIC_NUCLEI_SH_METADATA = Metadata(
    id="b433f3a14e198e3262f3306d8a51e090717c6fe0.boutiques",
    name="quantifyThalamicNuclei.sh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class QuantifyThalamicNucleiShOutputs(typing.NamedTuple):
    """
    Output object returned when calling `quantify_thalamic_nuclei_sh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    results_file: OutputPathType
    """The output file containing quantified thalamic nuclei results."""


def quantify_thalamic_nuclei_sh(
    output_file: str,
    analysis_id: str,
    subjects_directory: str | None = None,
    runner: Runner | None = None,
) -> QuantifyThalamicNucleiShOutputs:
    """
    Command-line tool to quantify thalamic nuclei using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_file: Output file for the results.
        analysis_id: Analysis ID for specificity.
        subjects_directory: Directory containing subject data.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `QuantifyThalamicNucleiShOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(QUANTIFY_THALAMIC_NUCLEI_SH_METADATA)
    cargs = []
    cargs.append("quantifyThalamicNuclei.sh")
    cargs.append(output_file)
    cargs.append(analysis_id)
    if subjects_directory is not None:
        cargs.append(subjects_directory)
    ret = QuantifyThalamicNucleiShOutputs(
        root=execution.output_file("."),
        results_file=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "QUANTIFY_THALAMIC_NUCLEI_SH_METADATA",
    "QuantifyThalamicNucleiShOutputs",
    "quantify_thalamic_nuclei_sh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REG2SUBJECT_METADATA = Metadata(
    id="bd548e7db5696c14e468b04f1fafbb638585f19c.boutiques",
    name="reg2subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Reg2subjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `reg2subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def reg2subject(
    regfile: InputPathType,
    runner: Runner | None = None,
) -> Reg2subjectOutputs:
    """
    Returns the name of the subject in the registration file, whether it is an LTA
    or register.dat file.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        regfile: Input registration file, either in LTA or register.dat format.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Reg2subjectOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(REG2SUBJECT_METADATA)
    cargs = []
    cargs.append("reg2subject")
    cargs.extend([
        "--r",
        execution.input_file(regfile)
    ])
    ret = Reg2subjectOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REG2SUBJECT_METADATA",
    "Reg2subjectOutputs",
    "reg2subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UNPACKIMADIR2_METADATA = Metadata(
    id="bdf6eb9c77635e9326080586e7654d60496c26b4.boutiques",
    name="unpackimadir2",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class Unpackimadir2Outputs(typing.NamedTuple):
    """
    Output object returned when calling `unpackimadir2(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def unpackimadir2(
    directory: InputPathType,
    runner: Runner | None = None,
) -> Unpackimadir2Outputs:
    """
    Tool to unpack image directories, from FreeSurfer suite.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        directory: Image directory to unpack.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Unpackimadir2Outputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UNPACKIMADIR2_METADATA)
    cargs = []
    cargs.append("unpackimadir2")
    cargs.append(execution.input_file(directory))
    ret = Unpackimadir2Outputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UNPACKIMADIR2_METADATA",
    "Unpackimadir2Outputs",
    "unpackimadir2",
]
